# coding: utf-8

"""
    Karbon Platform Services API reference.

    OpenAPI documentation for public facing Karbon Platform Services API  This API documentation is generated from source code using go-swagger. Do not edit the generated kps_api.json directly!  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: karbon-platform-services-api@nutanix.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import kps_api
from api.function_api import FunctionApi  # noqa: E501
from kps_api.rest import ApiException


class TestFunctionApi(unittest.TestCase):
    """FunctionApi unit test stubs"""

    def setUp(self):
        self.api = api.function_api.FunctionApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_function_create(self):
        """Test case for function_create

        Create a function.  # noqa: E501
        """
        pass

    def test_function_delete(self):
        """Test case for function_delete

        Delete a function by its ID.  # noqa: E501
        """
        pass

    def test_function_get(self):
        """Test case for function_get

        Get a function by its ID.  # noqa: E501
        """
        pass

    def test_function_list(self):
        """Test case for function_list

        Get functions.  # noqa: E501
        """
        pass

    def test_function_update(self):
        """Test case for function_update

        Update function by its ID  # noqa: E501
        """
        pass

    def test_project_get_functions(self):
        """Test case for project_get_functions

        Get functions by project ID.  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Karbon Platform Services API reference.

    OpenAPI documentation for public facing Karbon Platform Services API  This API documentation is generated from source code using go-swagger. Do not edit the generated kps_api.json directly!  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: karbon-platform-services-api@nutanix.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class EdgeUsageInfo(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'cpu_usage': 'str',
        'edge_build_num': 'str',
        'edge_version': 'str',
        'gpu_info': 'str',
        'gpu_usage': 'str',
        'kube_version': 'str',
        'memory_free_kb': 'str',
        'num_cpu': 'str',
        'os_version': 'str',
        'storage_free_kb': 'str',
        'total_memory_kb': 'str',
        'total_storage_kb': 'str',
        'edge_artifacts': 'dict(str, object)',
        'edge_id': 'str',
        'id': 'str'
    }

    attribute_map = {
        'cpu_usage': 'CPUUsage',
        'edge_build_num': 'EdgeBuildNum',
        'edge_version': 'EdgeVersion',
        'gpu_info': 'GPUInfo',
        'gpu_usage': 'GPUUsage',
        'kube_version': 'KubeVersion',
        'memory_free_kb': 'MemoryFreeKB',
        'num_cpu': 'NumCPU',
        'os_version': 'OSVersion',
        'storage_free_kb': 'StorageFreeKB',
        'total_memory_kb': 'TotalMemoryKB',
        'total_storage_kb': 'TotalStorageKB',
        'edge_artifacts': 'edgeArtifacts',
        'edge_id': 'edgeId',
        'id': 'id'
    }

    def __init__(self, cpu_usage=None, edge_build_num=None, edge_version=None, gpu_info=None, gpu_usage=None, kube_version=None, memory_free_kb=None, num_cpu=None, os_version=None, storage_free_kb=None, total_memory_kb=None, total_storage_kb=None, edge_artifacts=None, edge_id=None, id=None):  # noqa: E501
        """EdgeUsageInfo - a model defined in Swagger"""  # noqa: E501
        self._cpu_usage = None
        self._edge_build_num = None
        self._edge_version = None
        self._gpu_info = None
        self._gpu_usage = None
        self._kube_version = None
        self._memory_free_kb = None
        self._num_cpu = None
        self._os_version = None
        self._storage_free_kb = None
        self._total_memory_kb = None
        self._total_storage_kb = None
        self._edge_artifacts = None
        self._edge_id = None
        self._id = None
        self.discriminator = None
        if cpu_usage is not None:
            self.cpu_usage = cpu_usage
        if edge_build_num is not None:
            self.edge_build_num = edge_build_num
        if edge_version is not None:
            self.edge_version = edge_version
        if gpu_info is not None:
            self.gpu_info = gpu_info
        if gpu_usage is not None:
            self.gpu_usage = gpu_usage
        if kube_version is not None:
            self.kube_version = kube_version
        if memory_free_kb is not None:
            self.memory_free_kb = memory_free_kb
        if num_cpu is not None:
            self.num_cpu = num_cpu
        if os_version is not None:
            self.os_version = os_version
        if storage_free_kb is not None:
            self.storage_free_kb = storage_free_kb
        if total_memory_kb is not None:
            self.total_memory_kb = total_memory_kb
        if total_storage_kb is not None:
            self.total_storage_kb = total_storage_kb
        if edge_artifacts is not None:
            self.edge_artifacts = edge_artifacts
        self.edge_id = edge_id
        if id is not None:
            self.id = id

    @property
    def cpu_usage(self):
        """Gets the cpu_usage of this EdgeUsageInfo.  # noqa: E501

        Edge CPU usage.  # noqa: E501

        :return: The cpu_usage of this EdgeUsageInfo.  # noqa: E501
        :rtype: str
        """
        return self._cpu_usage

    @cpu_usage.setter
    def cpu_usage(self, cpu_usage):
        """Sets the cpu_usage of this EdgeUsageInfo.

        Edge CPU usage.  # noqa: E501

        :param cpu_usage: The cpu_usage of this EdgeUsageInfo.  # noqa: E501
        :type: str
        """

        self._cpu_usage = cpu_usage

    @property
    def edge_build_num(self):
        """Gets the edge_build_num of this EdgeUsageInfo.  # noqa: E501

        Edge build number.  # noqa: E501

        :return: The edge_build_num of this EdgeUsageInfo.  # noqa: E501
        :rtype: str
        """
        return self._edge_build_num

    @edge_build_num.setter
    def edge_build_num(self, edge_build_num):
        """Sets the edge_build_num of this EdgeUsageInfo.

        Edge build number.  # noqa: E501

        :param edge_build_num: The edge_build_num of this EdgeUsageInfo.  # noqa: E501
        :type: str
        """

        self._edge_build_num = edge_build_num

    @property
    def edge_version(self):
        """Gets the edge_version of this EdgeUsageInfo.  # noqa: E501

        Edge version.  # noqa: E501

        :return: The edge_version of this EdgeUsageInfo.  # noqa: E501
        :rtype: str
        """
        return self._edge_version

    @edge_version.setter
    def edge_version(self, edge_version):
        """Sets the edge_version of this EdgeUsageInfo.

        Edge version.  # noqa: E501

        :param edge_version: The edge_version of this EdgeUsageInfo.  # noqa: E501
        :type: str
        """

        self._edge_version = edge_version

    @property
    def gpu_info(self):
        """Gets the gpu_info of this EdgeUsageInfo.  # noqa: E501

        Information about GPUs associated with the edge.  # noqa: E501

        :return: The gpu_info of this EdgeUsageInfo.  # noqa: E501
        :rtype: str
        """
        return self._gpu_info

    @gpu_info.setter
    def gpu_info(self, gpu_info):
        """Sets the gpu_info of this EdgeUsageInfo.

        Information about GPUs associated with the edge.  # noqa: E501

        :param gpu_info: The gpu_info of this EdgeUsageInfo.  # noqa: E501
        :type: str
        """

        self._gpu_info = gpu_info

    @property
    def gpu_usage(self):
        """Gets the gpu_usage of this EdgeUsageInfo.  # noqa: E501

        Edge GPU Usage.  # noqa: E501

        :return: The gpu_usage of this EdgeUsageInfo.  # noqa: E501
        :rtype: str
        """
        return self._gpu_usage

    @gpu_usage.setter
    def gpu_usage(self, gpu_usage):
        """Sets the gpu_usage of this EdgeUsageInfo.

        Edge GPU Usage.  # noqa: E501

        :param gpu_usage: The gpu_usage of this EdgeUsageInfo.  # noqa: E501
        :type: str
        """

        self._gpu_usage = gpu_usage

    @property
    def kube_version(self):
        """Gets the kube_version of this EdgeUsageInfo.  # noqa: E501

        Edge Kubernetes version.  # noqa: E501

        :return: The kube_version of this EdgeUsageInfo.  # noqa: E501
        :rtype: str
        """
        return self._kube_version

    @kube_version.setter
    def kube_version(self, kube_version):
        """Sets the kube_version of this EdgeUsageInfo.

        Edge Kubernetes version.  # noqa: E501

        :param kube_version: The kube_version of this EdgeUsageInfo.  # noqa: E501
        :type: str
        """

        self._kube_version = kube_version

    @property
    def memory_free_kb(self):
        """Gets the memory_free_kb of this EdgeUsageInfo.  # noqa: E501

        Free (available) edge memory in KB.  # noqa: E501

        :return: The memory_free_kb of this EdgeUsageInfo.  # noqa: E501
        :rtype: str
        """
        return self._memory_free_kb

    @memory_free_kb.setter
    def memory_free_kb(self, memory_free_kb):
        """Sets the memory_free_kb of this EdgeUsageInfo.

        Free (available) edge memory in KB.  # noqa: E501

        :param memory_free_kb: The memory_free_kb of this EdgeUsageInfo.  # noqa: E501
        :type: str
        """

        self._memory_free_kb = memory_free_kb

    @property
    def num_cpu(self):
        """Gets the num_cpu of this EdgeUsageInfo.  # noqa: E501

        Number of CPUs assigned to the edge.  # noqa: E501

        :return: The num_cpu of this EdgeUsageInfo.  # noqa: E501
        :rtype: str
        """
        return self._num_cpu

    @num_cpu.setter
    def num_cpu(self, num_cpu):
        """Sets the num_cpu of this EdgeUsageInfo.

        Number of CPUs assigned to the edge.  # noqa: E501

        :param num_cpu: The num_cpu of this EdgeUsageInfo.  # noqa: E501
        :type: str
        """

        self._num_cpu = num_cpu

    @property
    def os_version(self):
        """Gets the os_version of this EdgeUsageInfo.  # noqa: E501

        Edge OS version  # noqa: E501

        :return: The os_version of this EdgeUsageInfo.  # noqa: E501
        :rtype: str
        """
        return self._os_version

    @os_version.setter
    def os_version(self, os_version):
        """Sets the os_version of this EdgeUsageInfo.

        Edge OS version  # noqa: E501

        :param os_version: The os_version of this EdgeUsageInfo.  # noqa: E501
        :type: str
        """

        self._os_version = os_version

    @property
    def storage_free_kb(self):
        """Gets the storage_free_kb of this EdgeUsageInfo.  # noqa: E501

        Free (available) edge storage in KB.  # noqa: E501

        :return: The storage_free_kb of this EdgeUsageInfo.  # noqa: E501
        :rtype: str
        """
        return self._storage_free_kb

    @storage_free_kb.setter
    def storage_free_kb(self, storage_free_kb):
        """Sets the storage_free_kb of this EdgeUsageInfo.

        Free (available) edge storage in KB.  # noqa: E501

        :param storage_free_kb: The storage_free_kb of this EdgeUsageInfo.  # noqa: E501
        :type: str
        """

        self._storage_free_kb = storage_free_kb

    @property
    def total_memory_kb(self):
        """Gets the total_memory_kb of this EdgeUsageInfo.  # noqa: E501

        Total edge memory in KB.  # noqa: E501

        :return: The total_memory_kb of this EdgeUsageInfo.  # noqa: E501
        :rtype: str
        """
        return self._total_memory_kb

    @total_memory_kb.setter
    def total_memory_kb(self, total_memory_kb):
        """Sets the total_memory_kb of this EdgeUsageInfo.

        Total edge memory in KB.  # noqa: E501

        :param total_memory_kb: The total_memory_kb of this EdgeUsageInfo.  # noqa: E501
        :type: str
        """

        self._total_memory_kb = total_memory_kb

    @property
    def total_storage_kb(self):
        """Gets the total_storage_kb of this EdgeUsageInfo.  # noqa: E501

        Total edge storage capacity in KB.  # noqa: E501

        :return: The total_storage_kb of this EdgeUsageInfo.  # noqa: E501
        :rtype: str
        """
        return self._total_storage_kb

    @total_storage_kb.setter
    def total_storage_kb(self, total_storage_kb):
        """Sets the total_storage_kb of this EdgeUsageInfo.

        Total edge storage capacity in KB.  # noqa: E501

        :param total_storage_kb: The total_storage_kb of this EdgeUsageInfo.  # noqa: E501
        :type: str
        """

        self._total_storage_kb = total_storage_kb

    @property
    def edge_artifacts(self):
        """Gets the edge_artifacts of this EdgeUsageInfo.  # noqa: E501

        Edge artifacts is a json object for passing edge ip and service ports  # noqa: E501

        :return: The edge_artifacts of this EdgeUsageInfo.  # noqa: E501
        :rtype: dict(str, object)
        """
        return self._edge_artifacts

    @edge_artifacts.setter
    def edge_artifacts(self, edge_artifacts):
        """Sets the edge_artifacts of this EdgeUsageInfo.

        Edge artifacts is a json object for passing edge ip and service ports  # noqa: E501

        :param edge_artifacts: The edge_artifacts of this EdgeUsageInfo.  # noqa: E501
        :type: dict(str, object)
        """

        self._edge_artifacts = edge_artifacts

    @property
    def edge_id(self):
        """Gets the edge_id of this EdgeUsageInfo.  # noqa: E501

        ID of the edge this entity belongs to  # noqa: E501

        :return: The edge_id of this EdgeUsageInfo.  # noqa: E501
        :rtype: str
        """
        return self._edge_id

    @edge_id.setter
    def edge_id(self, edge_id):
        """Sets the edge_id of this EdgeUsageInfo.

        ID of the edge this entity belongs to  # noqa: E501

        :param edge_id: The edge_id of this EdgeUsageInfo.  # noqa: E501
        :type: str
        """
        if edge_id is None:
            raise ValueError("Invalid value for `edge_id`, must not be `None`")  # noqa: E501

        self._edge_id = edge_id

    @property
    def id(self):
        """Gets the id of this EdgeUsageInfo.  # noqa: E501

        ID of the entity Maximum character length is 64 for project, category, and runtime environment, 36 for other entity types.  # noqa: E501

        :return: The id of this EdgeUsageInfo.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this EdgeUsageInfo.

        ID of the entity Maximum character length is 64 for project, category, and runtime environment, 36 for other entity types.  # noqa: E501

        :param id: The id of this EdgeUsageInfo.  # noqa: E501
        :type: str
        """

        self._id = id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(EdgeUsageInfo, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, EdgeUsageInfo):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Karbon Platform Services API reference.

    OpenAPI documentation for public facing Karbon Platform Services API  This API documentation is generated from source code using go-swagger. Do not edit the generated kps_api.json directly!  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: karbon-platform-services-api@nutanix.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class AppListItem(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'istio_sidecar': 'bool',
        'labels': 'dict(str, str)',
        'name': 'str'
    }

    attribute_map = {
        'istio_sidecar': 'istioSidecar',
        'labels': 'labels',
        'name': 'name'
    }

    def __init__(self, istio_sidecar=None, labels=None, name=None):  # noqa: E501
        """AppListItem - a model defined in Swagger"""  # noqa: E501
        self._istio_sidecar = None
        self._labels = None
        self._name = None
        self.discriminator = None
        self.istio_sidecar = istio_sidecar
        if labels is not None:
            self.labels = labels
        self.name = name

    @property
    def istio_sidecar(self):
        """Gets the istio_sidecar of this AppListItem.  # noqa: E501

        Define if all Pods related to the Workloads of this app has an IstioSidecar deployed  # noqa: E501

        :return: The istio_sidecar of this AppListItem.  # noqa: E501
        :rtype: bool
        """
        return self._istio_sidecar

    @istio_sidecar.setter
    def istio_sidecar(self, istio_sidecar):
        """Sets the istio_sidecar of this AppListItem.

        Define if all Pods related to the Workloads of this app has an IstioSidecar deployed  # noqa: E501

        :param istio_sidecar: The istio_sidecar of this AppListItem.  # noqa: E501
        :type: bool
        """
        if istio_sidecar is None:
            raise ValueError("Invalid value for `istio_sidecar`, must not be `None`")  # noqa: E501

        self._istio_sidecar = istio_sidecar

    @property
    def labels(self):
        """Gets the labels of this AppListItem.  # noqa: E501

        Labels for App  # noqa: E501

        :return: The labels of this AppListItem.  # noqa: E501
        :rtype: dict(str, str)
        """
        return self._labels

    @labels.setter
    def labels(self, labels):
        """Sets the labels of this AppListItem.

        Labels for App  # noqa: E501

        :param labels: The labels of this AppListItem.  # noqa: E501
        :type: dict(str, str)
        """

        self._labels = labels

    @property
    def name(self):
        """Gets the name of this AppListItem.  # noqa: E501

        Name of the application  # noqa: E501

        :return: The name of this AppListItem.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this AppListItem.

        Name of the application  # noqa: E501

        :param name: The name of this AppListItem.  # noqa: E501
        :type: str
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(AppListItem, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AppListItem):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Karbon Platform Services API reference.

    OpenAPI documentation for public facing Karbon Platform Services API  This API documentation is generated from source code using go-swagger. Do not edit the generated kps_api.json directly!  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: karbon-platform-services-api@nutanix.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class EdgeCertLockParam(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'duration_seconds': 'int',
        'edge_cluster_id': 'str',
        'locked': 'bool'
    }

    attribute_map = {
        'duration_seconds': 'durationSeconds',
        'edge_cluster_id': 'edgeClusterId',
        'locked': 'locked'
    }

    def __init__(self, duration_seconds=None, edge_cluster_id=None, locked=None):  # noqa: E501
        """EdgeCertLockParam - a model defined in Swagger"""  # noqa: E501
        self._duration_seconds = None
        self._edge_cluster_id = None
        self._locked = None
        self.discriminator = None
        if duration_seconds is not None:
            self.duration_seconds = duration_seconds
        self.edge_cluster_id = edge_cluster_id
        self.locked = locked

    @property
    def duration_seconds(self):
        """Gets the duration_seconds of this EdgeCertLockParam.  # noqa: E501

        If Locked is false and DurationSeconds is greater than 0, then first unlock the edge certification, then auto lock it after DurationSeconds seconds.  # noqa: E501

        :return: The duration_seconds of this EdgeCertLockParam.  # noqa: E501
        :rtype: int
        """
        return self._duration_seconds

    @duration_seconds.setter
    def duration_seconds(self, duration_seconds):
        """Sets the duration_seconds of this EdgeCertLockParam.

        If Locked is false and DurationSeconds is greater than 0, then first unlock the edge certification, then auto lock it after DurationSeconds seconds.  # noqa: E501

        :param duration_seconds: The duration_seconds of this EdgeCertLockParam.  # noqa: E501
        :type: int
        """

        self._duration_seconds = duration_seconds

    @property
    def edge_cluster_id(self):
        """Gets the edge_cluster_id of this EdgeCertLockParam.  # noqa: E501


        :return: The edge_cluster_id of this EdgeCertLockParam.  # noqa: E501
        :rtype: str
        """
        return self._edge_cluster_id

    @edge_cluster_id.setter
    def edge_cluster_id(self, edge_cluster_id):
        """Sets the edge_cluster_id of this EdgeCertLockParam.


        :param edge_cluster_id: The edge_cluster_id of this EdgeCertLockParam.  # noqa: E501
        :type: str
        """
        if edge_cluster_id is None:
            raise ValueError("Invalid value for `edge_cluster_id`, must not be `None`")  # noqa: E501

        self._edge_cluster_id = edge_cluster_id

    @property
    def locked(self):
        """Gets the locked of this EdgeCertLockParam.  # noqa: E501


        :return: The locked of this EdgeCertLockParam.  # noqa: E501
        :rtype: bool
        """
        return self._locked

    @locked.setter
    def locked(self, locked):
        """Sets the locked of this EdgeCertLockParam.


        :param locked: The locked of this EdgeCertLockParam.  # noqa: E501
        :type: bool
        """
        if locked is None:
            raise ValueError("Invalid value for `locked`, must not be `None`")  # noqa: E501

        self._locked = locked

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(EdgeCertLockParam, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, EdgeCertLockParam):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Karbon Platform Services API reference.

    OpenAPI documentation for public facing Karbon Platform Services API  This API documentation is generated from source code using go-swagger. Do not edit the generated kps_api.json directly!  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: karbon-platform-services-api@nutanix.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import kps_api
from api.service_domain_api import ServiceDomainApi  # noqa: E501
from kps_api.rest import ApiException


class TestServiceDomainApi(unittest.TestCase):
    """ServiceDomainApi unit test stubs"""

    def setUp(self):
        self.api = api.service_domain_api.ServiceDomainApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_project_get_service_domains(self):
        """Test case for project_get_service_domains

        Get all service domains associated with a project by project ID.  # noqa: E501
        """
        pass

    def test_service_domain_create(self):
        """Test case for service_domain_create

        Create service domain.  # noqa: E501
        """
        pass

    def test_service_domain_delete(self):
        """Test case for service_domain_delete

        Delete a service domain as specified by its ID.  # noqa: E501
        """
        pass

    def test_service_domain_get(self):
        """Test case for service_domain_get

        Get a service domain by its ID.  # noqa: E501
        """
        pass

    def test_service_domain_get_effective_profile(self):
        """Test case for service_domain_get_effective_profile

        Get a service domain effective profile by ID.  # noqa: E501
        """
        pass

    def test_service_domain_get_nodes(self):
        """Test case for service_domain_get_nodes

        Retrieves all nodes for a service domain by service domain ID {svcDomainId}.  # noqa: E501
        """
        pass

    def test_service_domain_get_nodes_info(self):
        """Test case for service_domain_get_nodes_info

        Get nodes info for a service domain by service domain ID.  # noqa: E501
        """
        pass

    def test_service_domain_list(self):
        """Test case for service_domain_list

        Get service domains.  # noqa: E501
        """
        pass

    def test_service_domain_update(self):
        """Test case for service_domain_update

        Update a service domain by its ID.  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Karbon Platform Services API reference.

    OpenAPI documentation for public facing Karbon Platform Services API  This API documentation is generated from source code using go-swagger. Do not edit the generated kps_api.json directly!  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: karbon-platform-services-api@nutanix.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import kps_api
from api.cloud_profile_api import CloudProfileApi  # noqa: E501
from kps_api.rest import ApiException


class TestCloudProfileApi(unittest.TestCase):
    """CloudProfileApi unit test stubs"""

    def setUp(self):
        self.api = api.cloud_profile_api.CloudProfileApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_cloud_profile_create(self):
        """Test case for cloud_profile_create

        Create a cloud profile.  # noqa: E501
        """
        pass

    def test_cloud_profile_delete(self):
        """Test case for cloud_profile_delete

        Delete a cloud profile by its ID.  # noqa: E501
        """
        pass

    def test_cloud_profile_get(self):
        """Test case for cloud_profile_get

        Get a cloud profile according to profile ID.  # noqa: E501
        """
        pass

    def test_cloud_profile_list(self):
        """Test case for cloud_profile_list

        Get all cloud service profiles.  # noqa: E501
        """
        pass

    def test_cloud_profile_update(self):
        """Test case for cloud_profile_update

        Update a cloud profile by its ID.  # noqa: E501
        """
        pass

    def test_project_get_cloud_profiles(self):
        """Test case for project_get_cloud_profiles

        Get cloud profiles according to project ID.  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Nutanix Karbon Platform Services API reference.

    OpenAPI documentation for public facing Nutanix Karbon Platform Services API

    OpenAPI spec version: 1.0
    Contact: karbon-platform-services-api@nutanix.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pathlib
from setuptools import setup, find_packages  # noqa: H301

NAME = "kps_api"
# To install the library, run the following
#
# python setup.py install
#
# prerequisite: setuptools
# http://pypi.python.org/pypi/setuptools

# The directory containing this file
HERE = pathlib.Path(__file__).parent

# The text of the README file
README = (HERE / "README.md").read_text()

REQUIRES = ["urllib3 >= 1.15", "six >= 1.10", "certifi", "python-dateutil"]
kps_api_packages = [
    "kps_api",
    "kps_api.api",
    "kps_api.models"
]

setup(
    name=NAME,
    version="1.3.10",
    description="Nutanix Karbon Platform Services Python SDK",
    author_email="karbon-platform-services-api@nutanix.com",
    long_description=README,
    long_description_content_type="text/markdown",
    url="https://github.com/nutanix/karbon-platform-services/tree/master/sdk/python",
    keywords=["Swagger", "Karbon Platform Services API reference."],
    install_requires=REQUIRES,
    packages=kps_api_packages,
    include_package_data=True
)



# coding: utf-8

"""
    Karbon Platform Services API reference.

    OpenAPI documentation for public facing Karbon Platform Services API  This API documentation is generated from source code using go-swagger. Do not edit the generated kps_api.json directly!  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: karbon-platform-services-api@nutanix.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six
from kps_api.models.category_info import CategoryInfo  # noqa: F401,E501
from kps_api.models.data_ifc_endpoint import DataIfcEndpoint  # noqa: F401,E501
from kps_api.models.data_source import DataSource  # noqa: F401,E501
from kps_api.models.retention_info import RetentionInfo  # noqa: F401,E501
from kps_api.models.transformation_args import TransformationArgs  # noqa: F401,E501


class DataStream(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'data_ifc_endpoints': 'list[DataIfcEndpoint]',
        'aws_cloud_region': 'str',
        'aws_stream_type': 'str',
        'az_stream_type': 'str',
        'cloud_creds_id': 'str',
        'cloud_type': 'str',
        'data_retention': 'list[RetentionInfo]',
        'data_type': 'str',
        'description': 'str',
        'destination': 'str',
        'edge_stream_type': 'str',
        'enable_sampling': 'bool',
        'end_point': 'str',
        'end_point_uri': 'str',
        'gcp_cloud_region': 'str',
        'gcp_stream_type': 'str',
        'id': 'str',
        'name': 'str',
        'origin': 'str',
        'origin_id': 'str',
        'origin_selectors': 'list[CategoryInfo]',
        'out_data_ifc': 'DataSource',
        'project_id': 'str',
        'sampling_interval': 'float',
        'size': 'float',
        'state': 'str',
        'transformation_args_list': 'list[TransformationArgs]'
    }

    attribute_map = {
        'data_ifc_endpoints': 'DataIfcEndpoints',
        'aws_cloud_region': 'awsCloudRegion',
        'aws_stream_type': 'awsStreamType',
        'az_stream_type': 'azStreamType',
        'cloud_creds_id': 'cloudCredsId',
        'cloud_type': 'cloudType',
        'data_retention': 'dataRetention',
        'data_type': 'dataType',
        'description': 'description',
        'destination': 'destination',
        'edge_stream_type': 'edgeStreamType',
        'enable_sampling': 'enableSampling',
        'end_point': 'endPoint',
        'end_point_uri': 'endPointURI',
        'gcp_cloud_region': 'gcpCloudRegion',
        'gcp_stream_type': 'gcpStreamType',
        'id': 'id',
        'name': 'name',
        'origin': 'origin',
        'origin_id': 'originId',
        'origin_selectors': 'originSelectors',
        'out_data_ifc': 'outDataIfc',
        'project_id': 'projectId',
        'sampling_interval': 'samplingInterval',
        'size': 'size',
        'state': 'state',
        'transformation_args_list': 'transformationArgsList'
    }

    def __init__(self, data_ifc_endpoints=None, aws_cloud_region=None, aws_stream_type=None, az_stream_type=None, cloud_creds_id=None, cloud_type=None, data_retention=None, data_type=None, description=None, destination=None, edge_stream_type=None, enable_sampling=None, end_point=None, end_point_uri=None, gcp_cloud_region=None, gcp_stream_type=None, id=None, name=None, origin=None, origin_id=None, origin_selectors=None, out_data_ifc=None, project_id=None, sampling_interval=None, size=None, state=None, transformation_args_list=None):  # noqa: E501
        """DataStream - a model defined in Swagger"""  # noqa: E501
        self._data_ifc_endpoints = None
        self._aws_cloud_region = None
        self._aws_stream_type = None
        self._az_stream_type = None
        self._cloud_creds_id = None
        self._cloud_type = None
        self._data_retention = None
        self._data_type = None
        self._description = None
        self._destination = None
        self._edge_stream_type = None
        self._enable_sampling = None
        self._end_point = None
        self._end_point_uri = None
        self._gcp_cloud_region = None
        self._gcp_stream_type = None
        self._id = None
        self._name = None
        self._origin = None
        self._origin_id = None
        self._origin_selectors = None
        self._out_data_ifc = None
        self._project_id = None
        self._sampling_interval = None
        self._size = None
        self._state = None
        self._transformation_args_list = None
        self.discriminator = None
        if data_ifc_endpoints is not None:
            self.data_ifc_endpoints = data_ifc_endpoints
        if aws_cloud_region is not None:
            self.aws_cloud_region = aws_cloud_region
        if aws_stream_type is not None:
            self.aws_stream_type = aws_stream_type
        if az_stream_type is not None:
            self.az_stream_type = az_stream_type
        if cloud_creds_id is not None:
            self.cloud_creds_id = cloud_creds_id
        if cloud_type is not None:
            self.cloud_type = cloud_type
        self.data_retention = data_retention
        self.data_type = data_type
        if description is not None:
            self.description = description
        self.destination = destination
        if edge_stream_type is not None:
            self.edge_stream_type = edge_stream_type
        self.enable_sampling = enable_sampling
        if end_point is not None:
            self.end_point = end_point
        if end_point_uri is not None:
            self.end_point_uri = end_point_uri
        if gcp_cloud_region is not None:
            self.gcp_cloud_region = gcp_cloud_region
        if gcp_stream_type is not None:
            self.gcp_stream_type = gcp_stream_type
        if id is not None:
            self.id = id
        self.name = name
        self.origin = origin
        if origin_id is not None:
            self.origin_id = origin_id
        self.origin_selectors = origin_selectors
        if out_data_ifc is not None:
            self.out_data_ifc = out_data_ifc
        if project_id is not None:
            self.project_id = project_id
        if sampling_interval is not None:
            self.sampling_interval = sampling_interval
        self.size = size
        if state is not None:
            self.state = state
        self.transformation_args_list = transformation_args_list

    @property
    def data_ifc_endpoints(self):
        """Gets the data_ifc_endpoints of this DataStream.  # noqa: E501

        Data Ifc endpoints connected to this datastream  # noqa: E501

        :return: The data_ifc_endpoints of this DataStream.  # noqa: E501
        :rtype: list[DataIfcEndpoint]
        """
        return self._data_ifc_endpoints

    @data_ifc_endpoints.setter
    def data_ifc_endpoints(self, data_ifc_endpoints):
        """Sets the data_ifc_endpoints of this DataStream.

        Data Ifc endpoints connected to this datastream  # noqa: E501

        :param data_ifc_endpoints: The data_ifc_endpoints of this DataStream.  # noqa: E501
        :type: list[DataIfcEndpoint]
        """

        self._data_ifc_endpoints = data_ifc_endpoints

    @property
    def aws_cloud_region(self):
        """Gets the aws_cloud_region of this DataStream.  # noqa: E501

        AWS region. Required if cloudType == AWS  # noqa: E501

        :return: The aws_cloud_region of this DataStream.  # noqa: E501
        :rtype: str
        """
        return self._aws_cloud_region

    @aws_cloud_region.setter
    def aws_cloud_region(self, aws_cloud_region):
        """Sets the aws_cloud_region of this DataStream.

        AWS region. Required if cloudType == AWS  # noqa: E501

        :param aws_cloud_region: The aws_cloud_region of this DataStream.  # noqa: E501
        :type: str
        """
        allowed_values = ["us-east-2", "us-east-1", "us-west-1", "us-west-2", "ap-northeast-1", "ap-northeast-2", "ap-northeast-3", "ap-south-1", "ap-southeast-1", "ap-southeast-2", "ca-central-1", "cn-north-1", "cn-northwest-1", "eu-central-1", "eu-west-1", "eu-west-2", "eu-west-3", "sa-east-1"]  # noqa: E501
        if aws_cloud_region not in allowed_values:
            raise ValueError(
                "Invalid value for `aws_cloud_region` ({0}), must be one of {1}"  # noqa: E501
                .format(aws_cloud_region, allowed_values)
            )

        self._aws_cloud_region = aws_cloud_region

    @property
    def aws_stream_type(self):
        """Gets the aws_stream_type of this DataStream.  # noqa: E501

        Type of the DataStream at AWS Cloud. Required if cloudType == AWS  # noqa: E501

        :return: The aws_stream_type of this DataStream.  # noqa: E501
        :rtype: str
        """
        return self._aws_stream_type

    @aws_stream_type.setter
    def aws_stream_type(self, aws_stream_type):
        """Sets the aws_stream_type of this DataStream.

        Type of the DataStream at AWS Cloud. Required if cloudType == AWS  # noqa: E501

        :param aws_stream_type: The aws_stream_type of this DataStream.  # noqa: E501
        :type: str
        """
        allowed_values = ["Kinesis", "SQS", "S3", "DynamoDB"]  # noqa: E501
        if aws_stream_type not in allowed_values:
            raise ValueError(
                "Invalid value for `aws_stream_type` ({0}), must be one of {1}"  # noqa: E501
                .format(aws_stream_type, allowed_values)
            )

        self._aws_stream_type = aws_stream_type

    @property
    def az_stream_type(self):
        """Gets the az_stream_type of this DataStream.  # noqa: E501

        Type of the DataStream at Azure Cloud. Required if cloudType == Azure  # noqa: E501

        :return: The az_stream_type of this DataStream.  # noqa: E501
        :rtype: str
        """
        return self._az_stream_type

    @az_stream_type.setter
    def az_stream_type(self, az_stream_type):
        """Sets the az_stream_type of this DataStream.

        Type of the DataStream at Azure Cloud. Required if cloudType == Azure  # noqa: E501

        :param az_stream_type: The az_stream_type of this DataStream.  # noqa: E501
        :type: str
        """
        allowed_values = ["Blob"]  # noqa: E501
        if az_stream_type not in allowed_values:
            raise ValueError(
                "Invalid value for `az_stream_type` ({0}), must be one of {1}"  # noqa: E501
                .format(az_stream_type, allowed_values)
            )

        self._az_stream_type = az_stream_type

    @property
    def cloud_creds_id(self):
        """Gets the cloud_creds_id of this DataStream.  # noqa: E501

        CloudCreds id. Required if destination == Cloud  # noqa: E501

        :return: The cloud_creds_id of this DataStream.  # noqa: E501
        :rtype: str
        """
        return self._cloud_creds_id

    @cloud_creds_id.setter
    def cloud_creds_id(self, cloud_creds_id):
        """Sets the cloud_creds_id of this DataStream.

        CloudCreds id. Required if destination == Cloud  # noqa: E501

        :param cloud_creds_id: The cloud_creds_id of this DataStream.  # noqa: E501
        :type: str
        """

        self._cloud_creds_id = cloud_creds_id

    @property
    def cloud_type(self):
        """Gets the cloud_type of this DataStream.  # noqa: E501

        Cloud type, required if destination == Cloud  # noqa: E501

        :return: The cloud_type of this DataStream.  # noqa: E501
        :rtype: str
        """
        return self._cloud_type

    @cloud_type.setter
    def cloud_type(self, cloud_type):
        """Sets the cloud_type of this DataStream.

        Cloud type, required if destination == Cloud  # noqa: E501

        :param cloud_type: The cloud_type of this DataStream.  # noqa: E501
        :type: str
        """
        allowed_values = ["AWS", "GCP", "Azure"]  # noqa: E501
        if cloud_type not in allowed_values:
            raise ValueError(
                "Invalid value for `cloud_type` ({0}), must be one of {1}"  # noqa: E501
                .format(cloud_type, allowed_values)
            )

        self._cloud_type = cloud_type

    @property
    def data_retention(self):
        """Gets the data_retention of this DataStream.  # noqa: E501

        Retention policy for this DataStream. Multiple RetentionInfo are combined using AND semantics. For example, retain data for 1 month AND up to 2 TB of data.  # noqa: E501

        :return: The data_retention of this DataStream.  # noqa: E501
        :rtype: list[RetentionInfo]
        """
        return self._data_retention

    @data_retention.setter
    def data_retention(self, data_retention):
        """Sets the data_retention of this DataStream.

        Retention policy for this DataStream. Multiple RetentionInfo are combined using AND semantics. For example, retain data for 1 month AND up to 2 TB of data.  # noqa: E501

        :param data_retention: The data_retention of this DataStream.  # noqa: E501
        :type: list[RetentionInfo]
        """
        if data_retention is None:
            raise ValueError("Invalid value for `data_retention`, must not be `None`")  # noqa: E501

        self._data_retention = data_retention

    @property
    def data_type(self):
        """Gets the data_type of this DataStream.  # noqa: E501

        Data type of the DataStream. For example, Temperature, Pressure, Image, Multiple, etc.  # noqa: E501

        :return: The data_type of this DataStream.  # noqa: E501
        :rtype: str
        """
        return self._data_type

    @data_type.setter
    def data_type(self, data_type):
        """Sets the data_type of this DataStream.

        Data type of the DataStream. For example, Temperature, Pressure, Image, Multiple, etc.  # noqa: E501

        :param data_type: The data_type of this DataStream.  # noqa: E501
        :type: str
        """
        if data_type is None:
            raise ValueError("Invalid value for `data_type`, must not be `None`")  # noqa: E501

        self._data_type = data_type

    @property
    def description(self):
        """Gets the description of this DataStream.  # noqa: E501

        The description of the DataStream  # noqa: E501

        :return: The description of this DataStream.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this DataStream.

        The description of the DataStream  # noqa: E501

        :param description: The description of this DataStream.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def destination(self):
        """Gets the destination of this DataStream.  # noqa: E501

        Destination of the DataStream. Either Edge or Cloud or DataInterface.  # noqa: E501

        :return: The destination of this DataStream.  # noqa: E501
        :rtype: str
        """
        return self._destination

    @destination.setter
    def destination(self, destination):
        """Sets the destination of this DataStream.

        Destination of the DataStream. Either Edge or Cloud or DataInterface.  # noqa: E501

        :param destination: The destination of this DataStream.  # noqa: E501
        :type: str
        """
        if destination is None:
            raise ValueError("Invalid value for `destination`, must not be `None`")  # noqa: E501
        allowed_values = ["Edge", "Cloud", "DataInterface"]  # noqa: E501
        if destination not in allowed_values:
            raise ValueError(
                "Invalid value for `destination` ({0}), must be one of {1}"  # noqa: E501
                .format(destination, allowed_values)
            )

        self._destination = destination

    @property
    def edge_stream_type(self):
        """Gets the edge_stream_type of this DataStream.  # noqa: E501

        Type of the DataStream at Edge. Required if destination == Edge  # noqa: E501

        :return: The edge_stream_type of this DataStream.  # noqa: E501
        :rtype: str
        """
        return self._edge_stream_type

    @edge_stream_type.setter
    def edge_stream_type(self, edge_stream_type):
        """Sets the edge_stream_type of this DataStream.

        Type of the DataStream at Edge. Required if destination == Edge  # noqa: E501

        :param edge_stream_type: The edge_stream_type of this DataStream.  # noqa: E501
        :type: str
        """
        allowed_values = ["Kafka", "ElasticSearch", "MQTT", "Connector", "None"]  # noqa: E501
        if edge_stream_type not in allowed_values:
            raise ValueError(
                "Invalid value for `edge_stream_type` ({0}), must be one of {1}"  # noqa: E501
                .format(edge_stream_type, allowed_values)
            )

        self._edge_stream_type = edge_stream_type

    @property
    def enable_sampling(self):
        """Gets the enable_sampling of this DataStream.  # noqa: E501

        Whether to turn sampling on. If true, then samplingInterval should be set as well.  # noqa: E501

        :return: The enable_sampling of this DataStream.  # noqa: E501
        :rtype: bool
        """
        return self._enable_sampling

    @enable_sampling.setter
    def enable_sampling(self, enable_sampling):
        """Sets the enable_sampling of this DataStream.

        Whether to turn sampling on. If true, then samplingInterval should be set as well.  # noqa: E501

        :param enable_sampling: The enable_sampling of this DataStream.  # noqa: E501
        :type: bool
        """
        if enable_sampling is None:
            raise ValueError("Invalid value for `enable_sampling`, must not be `None`")  # noqa: E501

        self._enable_sampling = enable_sampling

    @property
    def end_point(self):
        """Gets the end_point of this DataStream.  # noqa: E501

        End point of datastream. User specifies the endpoint.  # noqa: E501

        :return: The end_point of this DataStream.  # noqa: E501
        :rtype: str
        """
        return self._end_point

    @end_point.setter
    def end_point(self, end_point):
        """Sets the end_point of this DataStream.

        End point of datastream. User specifies the endpoint.  # noqa: E501

        :param end_point: The end_point of this DataStream.  # noqa: E501
        :type: str
        """

        self._end_point = end_point

    @property
    def end_point_uri(self):
        """Gets the end_point_uri of this DataStream.  # noqa: E501

        Endpoint URI Derived from existing fields required false  # noqa: E501

        :return: The end_point_uri of this DataStream.  # noqa: E501
        :rtype: str
        """
        return self._end_point_uri

    @end_point_uri.setter
    def end_point_uri(self, end_point_uri):
        """Sets the end_point_uri of this DataStream.

        Endpoint URI Derived from existing fields required false  # noqa: E501

        :param end_point_uri: The end_point_uri of this DataStream.  # noqa: E501
        :type: str
        """

        self._end_point_uri = end_point_uri

    @property
    def gcp_cloud_region(self):
        """Gets the gcp_cloud_region of this DataStream.  # noqa: E501

        GCP region. Required if cloudType == GCP  # noqa: E501

        :return: The gcp_cloud_region of this DataStream.  # noqa: E501
        :rtype: str
        """
        return self._gcp_cloud_region

    @gcp_cloud_region.setter
    def gcp_cloud_region(self, gcp_cloud_region):
        """Sets the gcp_cloud_region of this DataStream.

        GCP region. Required if cloudType == GCP  # noqa: E501

        :param gcp_cloud_region: The gcp_cloud_region of this DataStream.  # noqa: E501
        :type: str
        """
        allowed_values = ["northamerica-northeast1", "us-central1", "us-west1", "us-east4", "us-east1", "southamerica-east1", "europe-west1", "europe-west2", "europe-west3", "europe-west4", "asia-south1", "asia-southeast1", "asia-east1", "asia-northeast1", "australia-southeast1"]  # noqa: E501
        if gcp_cloud_region not in allowed_values:
            raise ValueError(
                "Invalid value for `gcp_cloud_region` ({0}), must be one of {1}"  # noqa: E501
                .format(gcp_cloud_region, allowed_values)
            )

        self._gcp_cloud_region = gcp_cloud_region

    @property
    def gcp_stream_type(self):
        """Gets the gcp_stream_type of this DataStream.  # noqa: E501

        Type of the DataStream at GCP Cloud. Required if cloudType == GCP  # noqa: E501

        :return: The gcp_stream_type of this DataStream.  # noqa: E501
        :rtype: str
        """
        return self._gcp_stream_type

    @gcp_stream_type.setter
    def gcp_stream_type(self, gcp_stream_type):
        """Sets the gcp_stream_type of this DataStream.

        Type of the DataStream at GCP Cloud. Required if cloudType == GCP  # noqa: E501

        :param gcp_stream_type: The gcp_stream_type of this DataStream.  # noqa: E501
        :type: str
        """
        allowed_values = ["PubSub", "CloudDatastore", "CloudSQL", "CloudStorage"]  # noqa: E501
        if gcp_stream_type not in allowed_values:
            raise ValueError(
                "Invalid value for `gcp_stream_type` ({0}), must be one of {1}"  # noqa: E501
                .format(gcp_stream_type, allowed_values)
            )

        self._gcp_stream_type = gcp_stream_type

    @property
    def id(self):
        """Gets the id of this DataStream.  # noqa: E501

        ID of the entity Maximum character length is 64 for project, category, and runtime environment, 36 for other entity types.  # noqa: E501

        :return: The id of this DataStream.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this DataStream.

        ID of the entity Maximum character length is 64 for project, category, and runtime environment, 36 for other entity types.  # noqa: E501

        :param id: The id of this DataStream.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def name(self):
        """Gets the name of this DataStream.  # noqa: E501

        Name of the DataStream. This is the published output (Kafka topic) name.  # noqa: E501

        :return: The name of this DataStream.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this DataStream.

        Name of the DataStream. This is the published output (Kafka topic) name.  # noqa: E501

        :param name: The name of this DataStream.  # noqa: E501
        :type: str
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def origin(self):
        """Gets the origin of this DataStream.  # noqa: E501

        The origin of the DataStream. Either 'Data Source' or 'Data Stream'  # noqa: E501

        :return: The origin of this DataStream.  # noqa: E501
        :rtype: str
        """
        return self._origin

    @origin.setter
    def origin(self, origin):
        """Sets the origin of this DataStream.

        The origin of the DataStream. Either 'Data Source' or 'Data Stream'  # noqa: E501

        :param origin: The origin of this DataStream.  # noqa: E501
        :type: str
        """
        if origin is None:
            raise ValueError("Invalid value for `origin`, must not be `None`")  # noqa: E501
        allowed_values = ["Data Source", "Data Stream"]  # noqa: E501
        if origin not in allowed_values:
            raise ValueError(
                "Invalid value for `origin` ({0}), must be one of {1}"  # noqa: E501
                .format(origin, allowed_values)
            )

        self._origin = origin

    @property
    def origin_id(self):
        """Gets the origin_id of this DataStream.  # noqa: E501

        If origin == 'Data Stream', then originId can be used in place of originSelectors to specify the origin data stream ID if the origin data stream is unique.  # noqa: E501

        :return: The origin_id of this DataStream.  # noqa: E501
        :rtype: str
        """
        return self._origin_id

    @origin_id.setter
    def origin_id(self, origin_id):
        """Sets the origin_id of this DataStream.

        If origin == 'Data Stream', then originId can be used in place of originSelectors to specify the origin data stream ID if the origin data stream is unique.  # noqa: E501

        :param origin_id: The origin_id of this DataStream.  # noqa: E501
        :type: str
        """

        self._origin_id = origin_id

    @property
    def origin_selectors(self):
        """Gets the origin_selectors of this DataStream.  # noqa: E501

        A list of CategoryInfo used as criteria to filter sources applicable to this DataStream.  # noqa: E501

        :return: The origin_selectors of this DataStream.  # noqa: E501
        :rtype: list[CategoryInfo]
        """
        return self._origin_selectors

    @origin_selectors.setter
    def origin_selectors(self, origin_selectors):
        """Sets the origin_selectors of this DataStream.

        A list of CategoryInfo used as criteria to filter sources applicable to this DataStream.  # noqa: E501

        :param origin_selectors: The origin_selectors of this DataStream.  # noqa: E501
        :type: list[CategoryInfo]
        """
        if origin_selectors is None:
            raise ValueError("Invalid value for `origin_selectors`, must not be `None`")  # noqa: E501

        self._origin_selectors = origin_selectors

    @property
    def out_data_ifc(self):
        """Gets the out_data_ifc of this DataStream.  # noqa: E501


        :return: The out_data_ifc of this DataStream.  # noqa: E501
        :rtype: DataSource
        """
        return self._out_data_ifc

    @out_data_ifc.setter
    def out_data_ifc(self, out_data_ifc):
        """Sets the out_data_ifc of this DataStream.


        :param out_data_ifc: The out_data_ifc of this DataStream.  # noqa: E501
        :type: DataSource
        """

        self._out_data_ifc = out_data_ifc

    @property
    def project_id(self):
        """Gets the project_id of this DataStream.  # noqa: E501

        ID of parent project. This should be required, but is not marked as such due to backward compatibility.  # noqa: E501

        :return: The project_id of this DataStream.  # noqa: E501
        :rtype: str
        """
        return self._project_id

    @project_id.setter
    def project_id(self, project_id):
        """Sets the project_id of this DataStream.

        ID of parent project. This should be required, but is not marked as such due to backward compatibility.  # noqa: E501

        :param project_id: The project_id of this DataStream.  # noqa: E501
        :type: str
        """

        self._project_id = project_id

    @property
    def sampling_interval(self):
        """Gets the sampling_interval of this DataStream.  # noqa: E501

        Sampling interval in seconds. The sampling interval applies to each mqtt/kafka topic separately.  # noqa: E501

        :return: The sampling_interval of this DataStream.  # noqa: E501
        :rtype: float
        """
        return self._sampling_interval

    @sampling_interval.setter
    def sampling_interval(self, sampling_interval):
        """Sets the sampling_interval of this DataStream.

        Sampling interval in seconds. The sampling interval applies to each mqtt/kafka topic separately.  # noqa: E501

        :param sampling_interval: The sampling_interval of this DataStream.  # noqa: E501
        :type: float
        """

        self._sampling_interval = sampling_interval

    @property
    def size(self):
        """Gets the size of this DataStream.  # noqa: E501

        Current size of the DataStream output in GB.  # noqa: E501

        :return: The size of this DataStream.  # noqa: E501
        :rtype: float
        """
        return self._size

    @size.setter
    def size(self, size):
        """Sets the size of this DataStream.

        Current size of the DataStream output in GB.  # noqa: E501

        :param size: The size of this DataStream.  # noqa: E501
        :type: float
        """
        if size is None:
            raise ValueError("Invalid value for `size`, must not be `None`")  # noqa: E501

        self._size = size

    @property
    def state(self):
        """Gets the state of this DataStream.  # noqa: E501

        State of this entity  # noqa: E501

        :return: The state of this DataStream.  # noqa: E501
        :rtype: str
        """
        return self._state

    @state.setter
    def state(self, state):
        """Sets the state of this DataStream.

        State of this entity  # noqa: E501

        :param state: The state of this DataStream.  # noqa: E501
        :type: str
        """

        self._state = state

    @property
    def transformation_args_list(self):
        """Gets the transformation_args_list of this DataStream.  # noqa: E501

        List of transformations (together with their args) to apply to the origin data to produce the destination data. Could be empty if no transformation required. Each entry is the id of the transformation Script to apply to input from origin to produce output to destination.  # noqa: E501

        :return: The transformation_args_list of this DataStream.  # noqa: E501
        :rtype: list[TransformationArgs]
        """
        return self._transformation_args_list

    @transformation_args_list.setter
    def transformation_args_list(self, transformation_args_list):
        """Sets the transformation_args_list of this DataStream.

        List of transformations (together with their args) to apply to the origin data to produce the destination data. Could be empty if no transformation required. Each entry is the id of the transformation Script to apply to input from origin to produce output to destination.  # noqa: E501

        :param transformation_args_list: The transformation_args_list of this DataStream.  # noqa: E501
        :type: list[TransformationArgs]
        """
        if transformation_args_list is None:
            raise ValueError("Invalid value for `transformation_args_list`, must not be `None`")  # noqa: E501

        self._transformation_args_list = transformation_args_list

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(DataStream, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DataStream):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Karbon Platform Services API reference.

    OpenAPI documentation for public facing Karbon Platform Services API  This API documentation is generated from source code using go-swagger. Do not edit the generated kps_api.json directly!  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: karbon-platform-services-api@nutanix.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class Iter8Criteria(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'metric': 'str',
        'sample_size': 'int',
        'stop_on_failure': 'bool',
        'tolerance': 'float',
        'tolerance_type': 'str'
    }

    attribute_map = {
        'metric': 'metric',
        'sample_size': 'sampleSize',
        'stop_on_failure': 'stopOnFailure',
        'tolerance': 'tolerance',
        'tolerance_type': 'toleranceType'
    }

    def __init__(self, metric=None, sample_size=None, stop_on_failure=None, tolerance=None, tolerance_type=None):  # noqa: E501
        """Iter8Criteria - a model defined in Swagger"""  # noqa: E501
        self._metric = None
        self._sample_size = None
        self._stop_on_failure = None
        self._tolerance = None
        self._tolerance_type = None
        self.discriminator = None
        if metric is not None:
            self.metric = metric
        if sample_size is not None:
            self.sample_size = sample_size
        if stop_on_failure is not None:
            self.stop_on_failure = stop_on_failure
        if tolerance is not None:
            self.tolerance = tolerance
        if tolerance_type is not None:
            self.tolerance_type = tolerance_type

    @property
    def metric(self):
        """Gets the metric of this Iter8Criteria.  # noqa: E501


        :return: The metric of this Iter8Criteria.  # noqa: E501
        :rtype: str
        """
        return self._metric

    @metric.setter
    def metric(self, metric):
        """Sets the metric of this Iter8Criteria.


        :param metric: The metric of this Iter8Criteria.  # noqa: E501
        :type: str
        """

        self._metric = metric

    @property
    def sample_size(self):
        """Gets the sample_size of this Iter8Criteria.  # noqa: E501


        :return: The sample_size of this Iter8Criteria.  # noqa: E501
        :rtype: int
        """
        return self._sample_size

    @sample_size.setter
    def sample_size(self, sample_size):
        """Sets the sample_size of this Iter8Criteria.


        :param sample_size: The sample_size of this Iter8Criteria.  # noqa: E501
        :type: int
        """

        self._sample_size = sample_size

    @property
    def stop_on_failure(self):
        """Gets the stop_on_failure of this Iter8Criteria.  # noqa: E501


        :return: The stop_on_failure of this Iter8Criteria.  # noqa: E501
        :rtype: bool
        """
        return self._stop_on_failure

    @stop_on_failure.setter
    def stop_on_failure(self, stop_on_failure):
        """Sets the stop_on_failure of this Iter8Criteria.


        :param stop_on_failure: The stop_on_failure of this Iter8Criteria.  # noqa: E501
        :type: bool
        """

        self._stop_on_failure = stop_on_failure

    @property
    def tolerance(self):
        """Gets the tolerance of this Iter8Criteria.  # noqa: E501


        :return: The tolerance of this Iter8Criteria.  # noqa: E501
        :rtype: float
        """
        return self._tolerance

    @tolerance.setter
    def tolerance(self, tolerance):
        """Sets the tolerance of this Iter8Criteria.


        :param tolerance: The tolerance of this Iter8Criteria.  # noqa: E501
        :type: float
        """

        self._tolerance = tolerance

    @property
    def tolerance_type(self):
        """Gets the tolerance_type of this Iter8Criteria.  # noqa: E501


        :return: The tolerance_type of this Iter8Criteria.  # noqa: E501
        :rtype: str
        """
        return self._tolerance_type

    @tolerance_type.setter
    def tolerance_type(self, tolerance_type):
        """Sets the tolerance_type of this Iter8Criteria.


        :param tolerance_type: The tolerance_type of this Iter8Criteria.  # noqa: E501
        :type: str
        """

        self._tolerance_type = tolerance_type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Iter8Criteria, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Iter8Criteria):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Karbon Platform Services API reference.

    OpenAPI documentation for public facing Karbon Platform Services API  This API documentation is generated from source code using go-swagger. Do not edit the generated kps_api.json directly!  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: karbon-platform-services-api@nutanix.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class DockerProfile(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'cloud_creds_id': 'str',
        'credentials': 'str',
        'description': 'str',
        'email': 'str',
        'id': 'str',
        'name': 'str',
        'pwd': 'str',
        'server': 'str',
        'type': 'str',
        'user_name': 'str'
    }

    attribute_map = {
        'cloud_creds_id': 'cloudCredsID',
        'credentials': 'credentials',
        'description': 'description',
        'email': 'email',
        'id': 'id',
        'name': 'name',
        'pwd': 'pwd',
        'server': 'server',
        'type': 'type',
        'user_name': 'userName'
    }

    def __init__(self, cloud_creds_id=None, credentials=None, description=None, email=None, id=None, name=None, pwd=None, server=None, type=None, user_name=None):  # noqa: E501
        """DockerProfile - a model defined in Swagger"""  # noqa: E501
        self._cloud_creds_id = None
        self._credentials = None
        self._description = None
        self._email = None
        self._id = None
        self._name = None
        self._pwd = None
        self._server = None
        self._type = None
        self._user_name = None
        self.discriminator = None
        if cloud_creds_id is not None:
            self.cloud_creds_id = cloud_creds_id
        if credentials is not None:
            self.credentials = credentials
        if description is not None:
            self.description = description
        if email is not None:
            self.email = email
        if id is not None:
            self.id = id
        self.name = name
        if pwd is not None:
            self.pwd = pwd
        self.server = server
        self.type = type
        if user_name is not None:
            self.user_name = user_name

    @property
    def cloud_creds_id(self):
        """Gets the cloud_creds_id of this DockerProfile.  # noqa: E501

        The CloudCreds to import Docker Profile from  # noqa: E501

        :return: The cloud_creds_id of this DockerProfile.  # noqa: E501
        :rtype: str
        """
        return self._cloud_creds_id

    @cloud_creds_id.setter
    def cloud_creds_id(self, cloud_creds_id):
        """Sets the cloud_creds_id of this DockerProfile.

        The CloudCreds to import Docker Profile from  # noqa: E501

        :param cloud_creds_id: The cloud_creds_id of this DockerProfile.  # noqa: E501
        :type: str
        """

        self._cloud_creds_id = cloud_creds_id

    @property
    def credentials(self):
        """Gets the credentials of this DockerProfile.  # noqa: E501

        The Credentials of the DockerProfile.  # noqa: E501

        :return: The credentials of this DockerProfile.  # noqa: E501
        :rtype: str
        """
        return self._credentials

    @credentials.setter
    def credentials(self, credentials):
        """Sets the credentials of this DockerProfile.

        The Credentials of the DockerProfile.  # noqa: E501

        :param credentials: The credentials of this DockerProfile.  # noqa: E501
        :type: str
        """

        self._credentials = credentials

    @property
    def description(self):
        """Gets the description of this DockerProfile.  # noqa: E501

        Description for the DockerProfile.  # noqa: E501

        :return: The description of this DockerProfile.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this DockerProfile.

        Description for the DockerProfile.  # noqa: E501

        :param description: The description of this DockerProfile.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def email(self):
        """Gets the email of this DockerProfile.  # noqa: E501

        DockerProfile  email.  # noqa: E501

        :return: The email of this DockerProfile.  # noqa: E501
        :rtype: str
        """
        return self._email

    @email.setter
    def email(self, email):
        """Sets the email of this DockerProfile.

        DockerProfile  email.  # noqa: E501

        :param email: The email of this DockerProfile.  # noqa: E501
        :type: str
        """

        self._email = email

    @property
    def id(self):
        """Gets the id of this DockerProfile.  # noqa: E501

        ID of the entity Maximum character length is 64 for project, category, and runtime environment, 36 for other entity types.  # noqa: E501

        :return: The id of this DockerProfile.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this DockerProfile.

        ID of the entity Maximum character length is 64 for project, category, and runtime environment, 36 for other entity types.  # noqa: E501

        :param id: The id of this DockerProfile.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def name(self):
        """Gets the name of this DockerProfile.  # noqa: E501

        Name for the DockerProfile.  # noqa: E501

        :return: The name of this DockerProfile.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this DockerProfile.

        Name for the DockerProfile.  # noqa: E501

        :param name: The name of this DockerProfile.  # noqa: E501
        :type: str
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def pwd(self):
        """Gets the pwd of this DockerProfile.  # noqa: E501

        DockerProfile  Password.  # noqa: E501

        :return: The pwd of this DockerProfile.  # noqa: E501
        :rtype: str
        """
        return self._pwd

    @pwd.setter
    def pwd(self, pwd):
        """Sets the pwd of this DockerProfile.

        DockerProfile  Password.  # noqa: E501

        :param pwd: The pwd of this DockerProfile.  # noqa: E501
        :type: str
        """

        self._pwd = pwd

    @property
    def server(self):
        """Gets the server of this DockerProfile.  # noqa: E501

        DockerProfile  server.  # noqa: E501

        :return: The server of this DockerProfile.  # noqa: E501
        :rtype: str
        """
        return self._server

    @server.setter
    def server(self, server):
        """Sets the server of this DockerProfile.

        DockerProfile  server.  # noqa: E501

        :param server: The server of this DockerProfile.  # noqa: E501
        :type: str
        """
        if server is None:
            raise ValueError("Invalid value for `server`, must not be `None`")  # noqa: E501

        self._server = server

    @property
    def type(self):
        """Gets the type of this DockerProfile.  # noqa: E501

        DockerProfile  type.  # noqa: E501

        :return: The type of this DockerProfile.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this DockerProfile.

        DockerProfile  type.  # noqa: E501

        :param type: The type of this DockerProfile.  # noqa: E501
        :type: str
        """
        if type is None:
            raise ValueError("Invalid value for `type`, must not be `None`")  # noqa: E501
        allowed_values = ["AWS", "GCP", "Azure", "ContainerRegistry"]  # noqa: E501
        if type not in allowed_values:
            raise ValueError(
                "Invalid value for `type` ({0}), must be one of {1}"  # noqa: E501
                .format(type, allowed_values)
            )

        self._type = type

    @property
    def user_name(self):
        """Gets the user_name of this DockerProfile.  # noqa: E501

        DockerProfile  user.  # noqa: E501

        :return: The user_name of this DockerProfile.  # noqa: E501
        :rtype: str
        """
        return self._user_name

    @user_name.setter
    def user_name(self, user_name):
        """Sets the user_name of this DockerProfile.

        DockerProfile  user.  # noqa: E501

        :param user_name: The user_name of this DockerProfile.  # noqa: E501
        :type: str
        """

        self._user_name = user_name

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(DockerProfile, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DockerProfile):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Karbon Platform Services API reference.

    OpenAPI documentation for public facing Karbon Platform Services API  This API documentation is generated from source code using go-swagger. Do not edit the generated kps_api.json directly!  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: karbon-platform-services-api@nutanix.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class MonitoringDashboardExternalLinkVariables(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'app': 'str',
        'namespace': 'str',
        'service': 'str',
        'version': 'str',
        'workload': 'str'
    }

    attribute_map = {
        'app': 'app',
        'namespace': 'namespace',
        'service': 'service',
        'version': 'version',
        'workload': 'workload'
    }

    def __init__(self, app=None, namespace=None, service=None, version=None, workload=None):  # noqa: E501
        """MonitoringDashboardExternalLinkVariables - a model defined in Swagger"""  # noqa: E501
        self._app = None
        self._namespace = None
        self._service = None
        self._version = None
        self._workload = None
        self.discriminator = None
        if app is not None:
            self.app = app
        if namespace is not None:
            self.namespace = namespace
        if service is not None:
            self.service = service
        if version is not None:
            self.version = version
        if workload is not None:
            self.workload = workload

    @property
    def app(self):
        """Gets the app of this MonitoringDashboardExternalLinkVariables.  # noqa: E501


        :return: The app of this MonitoringDashboardExternalLinkVariables.  # noqa: E501
        :rtype: str
        """
        return self._app

    @app.setter
    def app(self, app):
        """Sets the app of this MonitoringDashboardExternalLinkVariables.


        :param app: The app of this MonitoringDashboardExternalLinkVariables.  # noqa: E501
        :type: str
        """

        self._app = app

    @property
    def namespace(self):
        """Gets the namespace of this MonitoringDashboardExternalLinkVariables.  # noqa: E501


        :return: The namespace of this MonitoringDashboardExternalLinkVariables.  # noqa: E501
        :rtype: str
        """
        return self._namespace

    @namespace.setter
    def namespace(self, namespace):
        """Sets the namespace of this MonitoringDashboardExternalLinkVariables.


        :param namespace: The namespace of this MonitoringDashboardExternalLinkVariables.  # noqa: E501
        :type: str
        """

        self._namespace = namespace

    @property
    def service(self):
        """Gets the service of this MonitoringDashboardExternalLinkVariables.  # noqa: E501


        :return: The service of this MonitoringDashboardExternalLinkVariables.  # noqa: E501
        :rtype: str
        """
        return self._service

    @service.setter
    def service(self, service):
        """Sets the service of this MonitoringDashboardExternalLinkVariables.


        :param service: The service of this MonitoringDashboardExternalLinkVariables.  # noqa: E501
        :type: str
        """

        self._service = service

    @property
    def version(self):
        """Gets the version of this MonitoringDashboardExternalLinkVariables.  # noqa: E501


        :return: The version of this MonitoringDashboardExternalLinkVariables.  # noqa: E501
        :rtype: str
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this MonitoringDashboardExternalLinkVariables.


        :param version: The version of this MonitoringDashboardExternalLinkVariables.  # noqa: E501
        :type: str
        """

        self._version = version

    @property
    def workload(self):
        """Gets the workload of this MonitoringDashboardExternalLinkVariables.  # noqa: E501


        :return: The workload of this MonitoringDashboardExternalLinkVariables.  # noqa: E501
        :rtype: str
        """
        return self._workload

    @workload.setter
    def workload(self, workload):
        """Sets the workload of this MonitoringDashboardExternalLinkVariables.


        :param workload: The workload of this MonitoringDashboardExternalLinkVariables.  # noqa: E501
        :type: str
        """

        self._workload = workload

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(MonitoringDashboardExternalLinkVariables, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, MonitoringDashboardExternalLinkVariables):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Karbon Platform Services API reference.

    OpenAPI documentation for public facing Karbon Platform Services API  This API documentation is generated from source code using go-swagger. Do not edit the generated kps_api.json directly!  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: karbon-platform-services-api@nutanix.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class Iter8ExperimentItem(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'assessment_conclusion': 'list[str]',
        'baseline': 'str',
        'baseline_percentage': 'int',
        'candidate': 'str',
        'candidate_percentage': 'int',
        'created_at': 'int',
        'ended_at': 'int',
        'name': 'str',
        'namespace': 'str',
        'phase': 'str',
        'started_at': 'int',
        'status': 'str',
        'target_service': 'str',
        'target_service_namespace': 'str'
    }

    attribute_map = {
        'assessment_conclusion': 'assessmentConclusion',
        'baseline': 'baseline',
        'baseline_percentage': 'baselinePercentage',
        'candidate': 'candidate',
        'candidate_percentage': 'candidatePercentage',
        'created_at': 'createdAt',
        'ended_at': 'endedAt',
        'name': 'name',
        'namespace': 'namespace',
        'phase': 'phase',
        'started_at': 'startedAt',
        'status': 'status',
        'target_service': 'targetService',
        'target_service_namespace': 'targetServiceNamespace'
    }

    def __init__(self, assessment_conclusion=None, baseline=None, baseline_percentage=None, candidate=None, candidate_percentage=None, created_at=None, ended_at=None, name=None, namespace=None, phase=None, started_at=None, status=None, target_service=None, target_service_namespace=None):  # noqa: E501
        """Iter8ExperimentItem - a model defined in Swagger"""  # noqa: E501
        self._assessment_conclusion = None
        self._baseline = None
        self._baseline_percentage = None
        self._candidate = None
        self._candidate_percentage = None
        self._created_at = None
        self._ended_at = None
        self._name = None
        self._namespace = None
        self._phase = None
        self._started_at = None
        self._status = None
        self._target_service = None
        self._target_service_namespace = None
        self.discriminator = None
        if assessment_conclusion is not None:
            self.assessment_conclusion = assessment_conclusion
        if baseline is not None:
            self.baseline = baseline
        if baseline_percentage is not None:
            self.baseline_percentage = baseline_percentage
        if candidate is not None:
            self.candidate = candidate
        if candidate_percentage is not None:
            self.candidate_percentage = candidate_percentage
        if created_at is not None:
            self.created_at = created_at
        if ended_at is not None:
            self.ended_at = ended_at
        if name is not None:
            self.name = name
        if namespace is not None:
            self.namespace = namespace
        if phase is not None:
            self.phase = phase
        if started_at is not None:
            self.started_at = started_at
        if status is not None:
            self.status = status
        if target_service is not None:
            self.target_service = target_service
        if target_service_namespace is not None:
            self.target_service_namespace = target_service_namespace

    @property
    def assessment_conclusion(self):
        """Gets the assessment_conclusion of this Iter8ExperimentItem.  # noqa: E501


        :return: The assessment_conclusion of this Iter8ExperimentItem.  # noqa: E501
        :rtype: list[str]
        """
        return self._assessment_conclusion

    @assessment_conclusion.setter
    def assessment_conclusion(self, assessment_conclusion):
        """Sets the assessment_conclusion of this Iter8ExperimentItem.


        :param assessment_conclusion: The assessment_conclusion of this Iter8ExperimentItem.  # noqa: E501
        :type: list[str]
        """

        self._assessment_conclusion = assessment_conclusion

    @property
    def baseline(self):
        """Gets the baseline of this Iter8ExperimentItem.  # noqa: E501


        :return: The baseline of this Iter8ExperimentItem.  # noqa: E501
        :rtype: str
        """
        return self._baseline

    @baseline.setter
    def baseline(self, baseline):
        """Sets the baseline of this Iter8ExperimentItem.


        :param baseline: The baseline of this Iter8ExperimentItem.  # noqa: E501
        :type: str
        """

        self._baseline = baseline

    @property
    def baseline_percentage(self):
        """Gets the baseline_percentage of this Iter8ExperimentItem.  # noqa: E501


        :return: The baseline_percentage of this Iter8ExperimentItem.  # noqa: E501
        :rtype: int
        """
        return self._baseline_percentage

    @baseline_percentage.setter
    def baseline_percentage(self, baseline_percentage):
        """Sets the baseline_percentage of this Iter8ExperimentItem.


        :param baseline_percentage: The baseline_percentage of this Iter8ExperimentItem.  # noqa: E501
        :type: int
        """

        self._baseline_percentage = baseline_percentage

    @property
    def candidate(self):
        """Gets the candidate of this Iter8ExperimentItem.  # noqa: E501


        :return: The candidate of this Iter8ExperimentItem.  # noqa: E501
        :rtype: str
        """
        return self._candidate

    @candidate.setter
    def candidate(self, candidate):
        """Sets the candidate of this Iter8ExperimentItem.


        :param candidate: The candidate of this Iter8ExperimentItem.  # noqa: E501
        :type: str
        """

        self._candidate = candidate

    @property
    def candidate_percentage(self):
        """Gets the candidate_percentage of this Iter8ExperimentItem.  # noqa: E501


        :return: The candidate_percentage of this Iter8ExperimentItem.  # noqa: E501
        :rtype: int
        """
        return self._candidate_percentage

    @candidate_percentage.setter
    def candidate_percentage(self, candidate_percentage):
        """Sets the candidate_percentage of this Iter8ExperimentItem.


        :param candidate_percentage: The candidate_percentage of this Iter8ExperimentItem.  # noqa: E501
        :type: int
        """

        self._candidate_percentage = candidate_percentage

    @property
    def created_at(self):
        """Gets the created_at of this Iter8ExperimentItem.  # noqa: E501


        :return: The created_at of this Iter8ExperimentItem.  # noqa: E501
        :rtype: int
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this Iter8ExperimentItem.


        :param created_at: The created_at of this Iter8ExperimentItem.  # noqa: E501
        :type: int
        """

        self._created_at = created_at

    @property
    def ended_at(self):
        """Gets the ended_at of this Iter8ExperimentItem.  # noqa: E501


        :return: The ended_at of this Iter8ExperimentItem.  # noqa: E501
        :rtype: int
        """
        return self._ended_at

    @ended_at.setter
    def ended_at(self, ended_at):
        """Sets the ended_at of this Iter8ExperimentItem.


        :param ended_at: The ended_at of this Iter8ExperimentItem.  # noqa: E501
        :type: int
        """

        self._ended_at = ended_at

    @property
    def name(self):
        """Gets the name of this Iter8ExperimentItem.  # noqa: E501


        :return: The name of this Iter8ExperimentItem.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this Iter8ExperimentItem.


        :param name: The name of this Iter8ExperimentItem.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def namespace(self):
        """Gets the namespace of this Iter8ExperimentItem.  # noqa: E501


        :return: The namespace of this Iter8ExperimentItem.  # noqa: E501
        :rtype: str
        """
        return self._namespace

    @namespace.setter
    def namespace(self, namespace):
        """Sets the namespace of this Iter8ExperimentItem.


        :param namespace: The namespace of this Iter8ExperimentItem.  # noqa: E501
        :type: str
        """

        self._namespace = namespace

    @property
    def phase(self):
        """Gets the phase of this Iter8ExperimentItem.  # noqa: E501


        :return: The phase of this Iter8ExperimentItem.  # noqa: E501
        :rtype: str
        """
        return self._phase

    @phase.setter
    def phase(self, phase):
        """Sets the phase of this Iter8ExperimentItem.


        :param phase: The phase of this Iter8ExperimentItem.  # noqa: E501
        :type: str
        """

        self._phase = phase

    @property
    def started_at(self):
        """Gets the started_at of this Iter8ExperimentItem.  # noqa: E501


        :return: The started_at of this Iter8ExperimentItem.  # noqa: E501
        :rtype: int
        """
        return self._started_at

    @started_at.setter
    def started_at(self, started_at):
        """Sets the started_at of this Iter8ExperimentItem.


        :param started_at: The started_at of this Iter8ExperimentItem.  # noqa: E501
        :type: int
        """

        self._started_at = started_at

    @property
    def status(self):
        """Gets the status of this Iter8ExperimentItem.  # noqa: E501


        :return: The status of this Iter8ExperimentItem.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this Iter8ExperimentItem.


        :param status: The status of this Iter8ExperimentItem.  # noqa: E501
        :type: str
        """

        self._status = status

    @property
    def target_service(self):
        """Gets the target_service of this Iter8ExperimentItem.  # noqa: E501


        :return: The target_service of this Iter8ExperimentItem.  # noqa: E501
        :rtype: str
        """
        return self._target_service

    @target_service.setter
    def target_service(self, target_service):
        """Sets the target_service of this Iter8ExperimentItem.


        :param target_service: The target_service of this Iter8ExperimentItem.  # noqa: E501
        :type: str
        """

        self._target_service = target_service

    @property
    def target_service_namespace(self):
        """Gets the target_service_namespace of this Iter8ExperimentItem.  # noqa: E501


        :return: The target_service_namespace of this Iter8ExperimentItem.  # noqa: E501
        :rtype: str
        """
        return self._target_service_namespace

    @target_service_namespace.setter
    def target_service_namespace(self, target_service_namespace):
        """Sets the target_service_namespace of this Iter8ExperimentItem.


        :param target_service_namespace: The target_service_namespace of this Iter8ExperimentItem.  # noqa: E501
        :type: str
        """

        self._target_service_namespace = target_service_namespace

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Iter8ExperimentItem, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Iter8ExperimentItem):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Karbon Platform Services API reference.

    OpenAPI documentation for public facing Karbon Platform Services API  This API documentation is generated from source code using go-swagger. Do not edit the generated kps_api.json directly!  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: karbon-platform-services-api@nutanix.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from kps_api.api_client import ApiClient


class ServiceBindingApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def service_binding_create(self, body, authorization, **kwargs):  # noqa: E501
        """Create a Service Binding.  # noqa: E501

        Create a Service Binding  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.service_binding_create(body, authorization, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param ServiceBindingParam body: (required)
        :param str authorization: Format: Bearer <token>, with <token> from login API response. (required)
        :return: CreateDocumentResponseV2
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.service_binding_create_with_http_info(body, authorization, **kwargs)  # noqa: E501
        else:
            (data) = self.service_binding_create_with_http_info(body, authorization, **kwargs)  # noqa: E501
            return data

    def service_binding_create_with_http_info(self, body, authorization, **kwargs):  # noqa: E501
        """Create a Service Binding.  # noqa: E501

        Create a Service Binding  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.service_binding_create_with_http_info(body, authorization, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param ServiceBindingParam body: (required)
        :param str authorization: Format: Bearer <token>, with <token> from login API response. (required)
        :return: CreateDocumentResponseV2
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'authorization']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method service_binding_create" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `service_binding_create`")  # noqa: E501
        # verify the required parameter 'authorization' is set
        if ('authorization' not in params or
                params['authorization'] is None):
            raise ValueError("Missing the required parameter `authorization` when calling `service_binding_create`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}
        if 'authorization' in params:
            header_params['Authorization'] = params['authorization']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['BearerToken']  # noqa: E501

        return self.api_client.call_api(
            '/v1.0/servicebindings', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='CreateDocumentResponseV2',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def service_binding_delete(self, svc_binding_id, authorization, **kwargs):  # noqa: E501
        """Delete a Service Binding.  # noqa: E501

        Delete a Service Binding  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.service_binding_delete(svc_binding_id, authorization, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str svc_binding_id: Service Binding ID (required)
        :param str authorization: Format: Bearer <token>, with <token> from login API response. (required)
        :return: DeleteDocumentResponseV2
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.service_binding_delete_with_http_info(svc_binding_id, authorization, **kwargs)  # noqa: E501
        else:
            (data) = self.service_binding_delete_with_http_info(svc_binding_id, authorization, **kwargs)  # noqa: E501
            return data

    def service_binding_delete_with_http_info(self, svc_binding_id, authorization, **kwargs):  # noqa: E501
        """Delete a Service Binding.  # noqa: E501

        Delete a Service Binding  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.service_binding_delete_with_http_info(svc_binding_id, authorization, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str svc_binding_id: Service Binding ID (required)
        :param str authorization: Format: Bearer <token>, with <token> from login API response. (required)
        :return: DeleteDocumentResponseV2
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['svc_binding_id', 'authorization']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method service_binding_delete" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'svc_binding_id' is set
        if ('svc_binding_id' not in params or
                params['svc_binding_id'] is None):
            raise ValueError("Missing the required parameter `svc_binding_id` when calling `service_binding_delete`")  # noqa: E501
        # verify the required parameter 'authorization' is set
        if ('authorization' not in params or
                params['authorization'] is None):
            raise ValueError("Missing the required parameter `authorization` when calling `service_binding_delete`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'svc_binding_id' in params:
            path_params['svcBindingId'] = params['svc_binding_id']  # noqa: E501

        query_params = []

        header_params = {}
        if 'authorization' in params:
            header_params['Authorization'] = params['authorization']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['BearerToken']  # noqa: E501

        return self.api_client.call_api(
            '/v1.0/servicebindings/{svcBindingId}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='DeleteDocumentResponseV2',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def service_binding_get(self, svc_binding_id, authorization, **kwargs):  # noqa: E501
        """Get a Service Binding.  # noqa: E501

        Get a Service Binding  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.service_binding_get(svc_binding_id, authorization, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str svc_binding_id: Service Binding ID (required)
        :param str authorization: Format: Bearer <token>, with <token> from login API response. (required)
        :return: ServiceBinding
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.service_binding_get_with_http_info(svc_binding_id, authorization, **kwargs)  # noqa: E501
        else:
            (data) = self.service_binding_get_with_http_info(svc_binding_id, authorization, **kwargs)  # noqa: E501
            return data

    def service_binding_get_with_http_info(self, svc_binding_id, authorization, **kwargs):  # noqa: E501
        """Get a Service Binding.  # noqa: E501

        Get a Service Binding  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.service_binding_get_with_http_info(svc_binding_id, authorization, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str svc_binding_id: Service Binding ID (required)
        :param str authorization: Format: Bearer <token>, with <token> from login API response. (required)
        :return: ServiceBinding
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['svc_binding_id', 'authorization']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method service_binding_get" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'svc_binding_id' is set
        if ('svc_binding_id' not in params or
                params['svc_binding_id'] is None):
            raise ValueError("Missing the required parameter `svc_binding_id` when calling `service_binding_get`")  # noqa: E501
        # verify the required parameter 'authorization' is set
        if ('authorization' not in params or
                params['authorization'] is None):
            raise ValueError("Missing the required parameter `authorization` when calling `service_binding_get`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'svc_binding_id' in params:
            path_params['svcBindingId'] = params['svc_binding_id']  # noqa: E501

        query_params = []

        header_params = {}
        if 'authorization' in params:
            header_params['Authorization'] = params['authorization']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['BearerToken']  # noqa: E501

        return self.api_client.call_api(
            '/v1.0/servicebindings/{svcBindingId}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ServiceBinding',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def service_binding_list(self, authorization, **kwargs):  # noqa: E501
        """List Service Bindings.  # noqa: E501

        List Service Bindings  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.service_binding_list(authorization, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str authorization: Format: Bearer <token>, with <token> from login API response. (required)
        :param int page_index: 0-based index of the page to fetch results.
        :param int page_size: Item count of each page.
        :param list[str] order_by: Specify result order. Zero or more entries with format: &ltkey> [desc] where orderByKeys lists allowed keys in each response.
        :param str filter: Specify result filter. Format is similar to a SQL WHERE clause. For example, to filter object by name with prefix foo, use: name LIKE 'foo%'. Supported filter keys are the same as order by keys.
        :param str svc_class_id: Service Class ID
        :param str bind_resource_type: Bind resource type
        :param str bind_resource_id: Bind resource ID
        :return: ServiceBindingListPayload
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.service_binding_list_with_http_info(authorization, **kwargs)  # noqa: E501
        else:
            (data) = self.service_binding_list_with_http_info(authorization, **kwargs)  # noqa: E501
            return data

    def service_binding_list_with_http_info(self, authorization, **kwargs):  # noqa: E501
        """List Service Bindings.  # noqa: E501

        List Service Bindings  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.service_binding_list_with_http_info(authorization, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str authorization: Format: Bearer <token>, with <token> from login API response. (required)
        :param int page_index: 0-based index of the page to fetch results.
        :param int page_size: Item count of each page.
        :param list[str] order_by: Specify result order. Zero or more entries with format: &ltkey> [desc] where orderByKeys lists allowed keys in each response.
        :param str filter: Specify result filter. Format is similar to a SQL WHERE clause. For example, to filter object by name with prefix foo, use: name LIKE 'foo%'. Supported filter keys are the same as order by keys.
        :param str svc_class_id: Service Class ID
        :param str bind_resource_type: Bind resource type
        :param str bind_resource_id: Bind resource ID
        :return: ServiceBindingListPayload
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['authorization', 'page_index', 'page_size', 'order_by', 'filter', 'svc_class_id', 'bind_resource_type', 'bind_resource_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method service_binding_list" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'authorization' is set
        if ('authorization' not in params or
                params['authorization'] is None):
            raise ValueError("Missing the required parameter `authorization` when calling `service_binding_list`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'page_index' in params:
            query_params.append(('pageIndex', params['page_index']))  # noqa: E501
        if 'page_size' in params:
            query_params.append(('pageSize', params['page_size']))  # noqa: E501
        if 'order_by' in params:
            query_params.append(('orderBy', params['order_by']))  # noqa: E501
            collection_formats['orderBy'] = 'csv'  # noqa: E501
        if 'filter' in params:
            query_params.append(('filter', params['filter']))  # noqa: E501
        if 'svc_class_id' in params:
            query_params.append(('svcClassId', params['svc_class_id']))  # noqa: E501
        if 'bind_resource_type' in params:
            query_params.append(('bindResourceType', params['bind_resource_type']))  # noqa: E501
        if 'bind_resource_id' in params:
            query_params.append(('bindResourceId', params['bind_resource_id']))  # noqa: E501

        header_params = {}
        if 'authorization' in params:
            header_params['Authorization'] = params['authorization']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['BearerToken']  # noqa: E501

        return self.api_client.call_api(
            '/v1.0/servicebindings', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ServiceBindingListPayload',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def service_binding_status_list(self, svc_binding_id, authorization, **kwargs):  # noqa: E501
        """Get the status of Service Binding.  # noqa: E501

        Get the status of Service Binding on Service Domains  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.service_binding_status_list(svc_binding_id, authorization, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str svc_binding_id: Service Binding ID (required)
        :param str authorization: Format: Bearer <token>, with <token> from login API response. (required)
        :param int page_index: 0-based index of the page to fetch results.
        :param int page_size: Item count of each page.
        :param list[str] order_by: Specify result order. Zero or more entries with format: &ltkey> [desc] where orderByKeys lists allowed keys in each response.
        :param str filter: Specify result filter. Format is similar to a SQL WHERE clause. For example, to filter object by name with prefix foo, use: name LIKE 'foo%'. Supported filter keys are the same as order by keys.
        :param str svc_domain_id: Service Domain ID
        :param str svc_instance_id: Service Instance ID
        :return: ServiceBindingStatusListPayload
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.service_binding_status_list_with_http_info(svc_binding_id, authorization, **kwargs)  # noqa: E501
        else:
            (data) = self.service_binding_status_list_with_http_info(svc_binding_id, authorization, **kwargs)  # noqa: E501
            return data

    def service_binding_status_list_with_http_info(self, svc_binding_id, authorization, **kwargs):  # noqa: E501
        """Get the status of Service Binding.  # noqa: E501

        Get the status of Service Binding on Service Domains  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.service_binding_status_list_with_http_info(svc_binding_id, authorization, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str svc_binding_id: Service Binding ID (required)
        :param str authorization: Format: Bearer <token>, with <token> from login API response. (required)
        :param int page_index: 0-based index of the page to fetch results.
        :param int page_size: Item count of each page.
        :param list[str] order_by: Specify result order. Zero or more entries with format: &ltkey> [desc] where orderByKeys lists allowed keys in each response.
        :param str filter: Specify result filter. Format is similar to a SQL WHERE clause. For example, to filter object by name with prefix foo, use: name LIKE 'foo%'. Supported filter keys are the same as order by keys.
        :param str svc_domain_id: Service Domain ID
        :param str svc_instance_id: Service Instance ID
        :return: ServiceBindingStatusListPayload
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['svc_binding_id', 'authorization', 'page_index', 'page_size', 'order_by', 'filter', 'svc_domain_id', 'svc_instance_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method service_binding_status_list" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'svc_binding_id' is set
        if ('svc_binding_id' not in params or
                params['svc_binding_id'] is None):
            raise ValueError("Missing the required parameter `svc_binding_id` when calling `service_binding_status_list`")  # noqa: E501
        # verify the required parameter 'authorization' is set
        if ('authorization' not in params or
                params['authorization'] is None):
            raise ValueError("Missing the required parameter `authorization` when calling `service_binding_status_list`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'svc_binding_id' in params:
            path_params['svcBindingId'] = params['svc_binding_id']  # noqa: E501

        query_params = []
        if 'page_index' in params:
            query_params.append(('pageIndex', params['page_index']))  # noqa: E501
        if 'page_size' in params:
            query_params.append(('pageSize', params['page_size']))  # noqa: E501
        if 'order_by' in params:
            query_params.append(('orderBy', params['order_by']))  # noqa: E501
            collection_formats['orderBy'] = 'csv'  # noqa: E501
        if 'filter' in params:
            query_params.append(('filter', params['filter']))  # noqa: E501
        if 'svc_domain_id' in params:
            query_params.append(('svcDomainId', params['svc_domain_id']))  # noqa: E501
        if 'svc_instance_id' in params:
            query_params.append(('svcInstanceId', params['svc_instance_id']))  # noqa: E501

        header_params = {}
        if 'authorization' in params:
            header_params['Authorization'] = params['authorization']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['BearerToken']  # noqa: E501

        return self.api_client.call_api(
            '/v1.0/servicebindings/{svcBindingId}/status', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ServiceBindingStatusListPayload',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Karbon Platform Services API reference.

    OpenAPI documentation for public facing Karbon Platform Services API  This API documentation is generated from source code using go-swagger. Do not edit the generated kps_api.json directly!  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: karbon-platform-services-api@nutanix.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import kps_api
from api.kiali_api import KialiApi  # noqa: E501
from kps_api.rest import ApiException


class TestKialiApi(unittest.TestCase):
    """KialiApi unit test stubs"""

    def setUp(self):
        self.api = api.kiali_api.KialiApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_app_dashboard(self):
        """Test case for app_dashboard

        """
        pass

    def test_app_details(self):
        """Test case for app_details

        """
        pass

    def test_app_health(self):
        """Test case for app_health

        """
        pass

    def test_app_list(self):
        """Test case for app_list

        """
        pass

    def test_app_metrics(self):
        """Test case for app_metrics

        """
        pass

    def test_error_traces(self):
        """Test case for error_traces

        """
        pass

    def test_get_config(self):
        """Test case for get_config

        """
        pass

    def test_get_status(self):
        """Test case for get_status

        """
        pass

    def test_graph_app(self):
        """Test case for graph_app

        """
        pass

    def test_graph_app_version(self):
        """Test case for graph_app_version

        """
        pass

    def test_graph_namespaces(self):
        """Test case for graph_namespaces

        The backing JSON for a namespaces graph.  # noqa: E501
        """
        pass

    def test_graph_service(self):
        """Test case for graph_service

        The backing JSON for a service node detail graph.  # noqa: E501
        """
        pass

    def test_graph_workload(self):
        """Test case for graph_workload

        The backing JSON for a workload node detail graph.  # noqa: E501
        """
        pass

    def test_istio_config_list(self):
        """Test case for istio_config_list

        """
        pass

    def test_istio_status(self):
        """Test case for istio_status

        """
        pass

    def test_namespace_health(self):
        """Test case for namespace_health

        """
        pass

    def test_namespace_list(self):
        """Test case for namespace_list

        """
        pass

    def test_namespace_metrics(self):
        """Test case for namespace_metrics

        """
        pass

    def test_namespace_tls(self):
        """Test case for namespace_tls

        """
        pass

    def test_namespace_validations(self):
        """Test case for namespace_validations

        """
        pass

    def test_pod_details(self):
        """Test case for pod_details

        """
        pass

    def test_pod_logs(self):
        """Test case for pod_logs

        """
        pass

    def test_root(self):
        """Test case for root

        """
        pass

    def test_service_dashboard(self):
        """Test case for service_dashboard

        """
        pass

    def test_service_details(self):
        """Test case for service_details

        """
        pass

    def test_service_health(self):
        """Test case for service_health

        """
        pass

    def test_service_list(self):
        """Test case for service_list

        """
        pass

    def test_service_metrics(self):
        """Test case for service_metrics

        """
        pass

    def test_spans_list(self):
        """Test case for spans_list

        """
        pass

    def test_traces_detail(self):
        """Test case for traces_detail

        """
        pass

    def test_workload_dashboard(self):
        """Test case for workload_dashboard

        """
        pass

    def test_workload_details(self):
        """Test case for workload_details

        """
        pass

    def test_workload_health(self):
        """Test case for workload_health

        """
        pass

    def test_workload_list(self):
        """Test case for workload_list

        """
        pass

    def test_workload_metrics(self):
        """Test case for workload_metrics

        """
        pass


if __name__ == '__main__':
    unittest.main()



from __future__ import absolute_import

# flake8: noqa

# import apis into api package
from kps_api.api.application_api import ApplicationApi
from kps_api.api.application_status_api import ApplicationStatusApi
from kps_api.api.auditlog_api import AuditlogApi
from kps_api.api.auth_api import AuthApi
from kps_api.api.category_api import CategoryApi
from kps_api.api.certificate_api import CertificateApi
from kps_api.api.cloud_profile_api import CloudProfileApi
from kps_api.api.connector_class_api import ConnectorClassApi
from kps_api.api.connector_config_api import ConnectorConfigApi
from kps_api.api.connector_instance_api import ConnectorInstanceApi
from kps_api.api.connector_stream_api import ConnectorStreamApi
from kps_api.api.container_registry_api import ContainerRegistryApi
from kps_api.api.data_pipeline_api import DataPipelineApi
from kps_api.api.data_source_api import DataSourceApi
from kps_api.api.event_api import EventApi
from kps_api.api.function_api import FunctionApi
from kps_api.api.http_service_proxy_api import HTTPServiceProxyApi
from kps_api.api.helm_api import HelmApi
from kps_api.api.kiali_api import KialiApi
from kps_api.api.kubernetes_cluster_api import KubernetesClusterApi
from kps_api.api.log_api import LogApi
from kps_api.api.log_collector_api import LogCollectorApi
from kps_api.api.ml_model_status_api import MLModelStatusApi
from kps_api.api.ml_model_api import MLModelApi
from kps_api.api.node_api import NodeApi
from kps_api.api.node_info_api import NodeInfoApi
from kps_api.api.project_api import ProjectApi
from kps_api.api.runtime_environment_api import RuntimeEnvironmentApi
from kps_api.api.ssh_api import SSHApi
from kps_api.api.service_binding_api import ServiceBindingApi
from kps_api.api.service_class_api import ServiceClassApi
from kps_api.api.service_domain_api import ServiceDomainApi
from kps_api.api.service_domain_cluster_api import ServiceDomainClusterApi
from kps_api.api.service_domain_info_api import ServiceDomainInfoApi
from kps_api.api.service_instance_api import ServiceInstanceApi
from kps_api.api.storage_profile_api import StorageProfileApi
from kps_api.api.user_api import UserApi
from kps_api.api.user_api_token_api import UserAPITokenApi
from kps_api.api.user_public_key_api import UserPublicKeyApi



# coding: utf-8

"""
    Karbon Platform Services API reference.

    OpenAPI documentation for public facing Karbon Platform Services API  This API documentation is generated from source code using go-swagger. Do not edit the generated kps_api.json directly!  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: karbon-platform-services-api@nutanix.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six
from kps_api.models.dashboard_response import DashboardResponse  # noqa: F401,E501
from kps_api.models.graph_config import GraphConfig  # noqa: F401,E501
from kps_api.models.service_details import ServiceDetails  # noqa: F401,E501
from kps_api.models.service_health import ServiceHealth  # noqa: F401,E501


class ServicesOverview(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'detail': 'ServiceDetails',
        'graph': 'GraphConfig',
        'health': 'ServiceHealth',
        'inbound': 'DashboardResponse',
        'outbound': 'DashboardResponse'
    }

    attribute_map = {
        'detail': 'detail',
        'graph': 'graph',
        'health': 'health',
        'inbound': 'inbound',
        'outbound': 'outbound'
    }

    def __init__(self, detail=None, graph=None, health=None, inbound=None, outbound=None):  # noqa: E501
        """ServicesOverview - a model defined in Swagger"""  # noqa: E501
        self._detail = None
        self._graph = None
        self._health = None
        self._inbound = None
        self._outbound = None
        self.discriminator = None
        if detail is not None:
            self.detail = detail
        if graph is not None:
            self.graph = graph
        if health is not None:
            self.health = health
        if inbound is not None:
            self.inbound = inbound
        if outbound is not None:
            self.outbound = outbound

    @property
    def detail(self):
        """Gets the detail of this ServicesOverview.  # noqa: E501


        :return: The detail of this ServicesOverview.  # noqa: E501
        :rtype: ServiceDetails
        """
        return self._detail

    @detail.setter
    def detail(self, detail):
        """Sets the detail of this ServicesOverview.


        :param detail: The detail of this ServicesOverview.  # noqa: E501
        :type: ServiceDetails
        """

        self._detail = detail

    @property
    def graph(self):
        """Gets the graph of this ServicesOverview.  # noqa: E501


        :return: The graph of this ServicesOverview.  # noqa: E501
        :rtype: GraphConfig
        """
        return self._graph

    @graph.setter
    def graph(self, graph):
        """Sets the graph of this ServicesOverview.


        :param graph: The graph of this ServicesOverview.  # noqa: E501
        :type: GraphConfig
        """

        self._graph = graph

    @property
    def health(self):
        """Gets the health of this ServicesOverview.  # noqa: E501


        :return: The health of this ServicesOverview.  # noqa: E501
        :rtype: ServiceHealth
        """
        return self._health

    @health.setter
    def health(self, health):
        """Sets the health of this ServicesOverview.


        :param health: The health of this ServicesOverview.  # noqa: E501
        :type: ServiceHealth
        """

        self._health = health

    @property
    def inbound(self):
        """Gets the inbound of this ServicesOverview.  # noqa: E501


        :return: The inbound of this ServicesOverview.  # noqa: E501
        :rtype: DashboardResponse
        """
        return self._inbound

    @inbound.setter
    def inbound(self, inbound):
        """Sets the inbound of this ServicesOverview.


        :param inbound: The inbound of this ServicesOverview.  # noqa: E501
        :type: DashboardResponse
        """

        self._inbound = inbound

    @property
    def outbound(self):
        """Gets the outbound of this ServicesOverview.  # noqa: E501


        :return: The outbound of this ServicesOverview.  # noqa: E501
        :rtype: DashboardResponse
        """
        return self._outbound

    @outbound.setter
    def outbound(self, outbound):
        """Sets the outbound of this ServicesOverview.


        :param outbound: The outbound of this ServicesOverview.  # noqa: E501
        :type: DashboardResponse
        """

        self._outbound = outbound

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ServicesOverview, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ServicesOverview):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Karbon Platform Services API reference.

    OpenAPI documentation for public facing Karbon Platform Services API  This API documentation is generated from source code using go-swagger. Do not edit the generated kps_api.json directly!  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: karbon-platform-services-api@nutanix.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six
from kps_api.models.node_role import NodeRole  # noqa: F401,E501


class EdgeDeviceWithClusterInfo(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'bootstrap_master_ssh_public_key': 'str',
        'cluster_id': 'str',
        'description': 'str',
        'gateway': 'str',
        'id': 'str',
        'ip_address': 'str',
        'is_bootstrap_master': 'bool',
        'name': 'str',
        'role': 'NodeRole',
        'serial_number': 'str',
        'subnet': 'str'
    }

    attribute_map = {
        'bootstrap_master_ssh_public_key': 'bootstrapMasterSshPublicKey',
        'cluster_id': 'clusterId',
        'description': 'description',
        'gateway': 'gateway',
        'id': 'id',
        'ip_address': 'ipAddress',
        'is_bootstrap_master': 'isBootstrapMaster',
        'name': 'name',
        'role': 'role',
        'serial_number': 'serialNumber',
        'subnet': 'subnet'
    }

    def __init__(self, bootstrap_master_ssh_public_key=None, cluster_id=None, description=None, gateway=None, id=None, ip_address=None, is_bootstrap_master=None, name=None, role=None, serial_number=None, subnet=None):  # noqa: E501
        """EdgeDeviceWithClusterInfo - a model defined in Swagger"""  # noqa: E501
        self._bootstrap_master_ssh_public_key = None
        self._cluster_id = None
        self._description = None
        self._gateway = None
        self._id = None
        self._ip_address = None
        self._is_bootstrap_master = None
        self._name = None
        self._role = None
        self._serial_number = None
        self._subnet = None
        self.discriminator = None
        if bootstrap_master_ssh_public_key is not None:
            self.bootstrap_master_ssh_public_key = bootstrap_master_ssh_public_key
        self.cluster_id = cluster_id
        if description is not None:
            self.description = description
        self.gateway = gateway
        if id is not None:
            self.id = id
        self.ip_address = ip_address
        self.is_bootstrap_master = is_bootstrap_master
        self.name = name
        if role is not None:
            self.role = role
        self.serial_number = serial_number
        self.subnet = subnet

    @property
    def bootstrap_master_ssh_public_key(self):
        """Gets the bootstrap_master_ssh_public_key of this EdgeDeviceWithClusterInfo.  # noqa: E501


        :return: The bootstrap_master_ssh_public_key of this EdgeDeviceWithClusterInfo.  # noqa: E501
        :rtype: str
        """
        return self._bootstrap_master_ssh_public_key

    @bootstrap_master_ssh_public_key.setter
    def bootstrap_master_ssh_public_key(self, bootstrap_master_ssh_public_key):
        """Sets the bootstrap_master_ssh_public_key of this EdgeDeviceWithClusterInfo.


        :param bootstrap_master_ssh_public_key: The bootstrap_master_ssh_public_key of this EdgeDeviceWithClusterInfo.  # noqa: E501
        :type: str
        """

        self._bootstrap_master_ssh_public_key = bootstrap_master_ssh_public_key

    @property
    def cluster_id(self):
        """Gets the cluster_id of this EdgeDeviceWithClusterInfo.  # noqa: E501

        ID of the cluster this entity belongs to  # noqa: E501

        :return: The cluster_id of this EdgeDeviceWithClusterInfo.  # noqa: E501
        :rtype: str
        """
        return self._cluster_id

    @cluster_id.setter
    def cluster_id(self, cluster_id):
        """Sets the cluster_id of this EdgeDeviceWithClusterInfo.

        ID of the cluster this entity belongs to  # noqa: E501

        :param cluster_id: The cluster_id of this EdgeDeviceWithClusterInfo.  # noqa: E501
        :type: str
        """
        if cluster_id is None:
            raise ValueError("Invalid value for `cluster_id`, must not be `None`")  # noqa: E501

        self._cluster_id = cluster_id

    @property
    def description(self):
        """Gets the description of this EdgeDeviceWithClusterInfo.  # noqa: E501

        EdgeDevice description  # noqa: E501

        :return: The description of this EdgeDeviceWithClusterInfo.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this EdgeDeviceWithClusterInfo.

        EdgeDevice description  # noqa: E501

        :param description: The description of this EdgeDeviceWithClusterInfo.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def gateway(self):
        """Gets the gateway of this EdgeDeviceWithClusterInfo.  # noqa: E501

        Edge Device Gateway IP address  # noqa: E501

        :return: The gateway of this EdgeDeviceWithClusterInfo.  # noqa: E501
        :rtype: str
        """
        return self._gateway

    @gateway.setter
    def gateway(self, gateway):
        """Sets the gateway of this EdgeDeviceWithClusterInfo.

        Edge Device Gateway IP address  # noqa: E501

        :param gateway: The gateway of this EdgeDeviceWithClusterInfo.  # noqa: E501
        :type: str
        """
        if gateway is None:
            raise ValueError("Invalid value for `gateway`, must not be `None`")  # noqa: E501

        self._gateway = gateway

    @property
    def id(self):
        """Gets the id of this EdgeDeviceWithClusterInfo.  # noqa: E501

        ID of the entity Maximum character length is 64 for project, category, and runtime environment, 36 for other entity types.  # noqa: E501

        :return: The id of this EdgeDeviceWithClusterInfo.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this EdgeDeviceWithClusterInfo.

        ID of the entity Maximum character length is 64 for project, category, and runtime environment, 36 for other entity types.  # noqa: E501

        :param id: The id of this EdgeDeviceWithClusterInfo.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def ip_address(self):
        """Gets the ip_address of this EdgeDeviceWithClusterInfo.  # noqa: E501

        Edge device IP Address  # noqa: E501

        :return: The ip_address of this EdgeDeviceWithClusterInfo.  # noqa: E501
        :rtype: str
        """
        return self._ip_address

    @ip_address.setter
    def ip_address(self, ip_address):
        """Sets the ip_address of this EdgeDeviceWithClusterInfo.

        Edge device IP Address  # noqa: E501

        :param ip_address: The ip_address of this EdgeDeviceWithClusterInfo.  # noqa: E501
        :type: str
        """
        if ip_address is None:
            raise ValueError("Invalid value for `ip_address`, must not be `None`")  # noqa: E501

        self._ip_address = ip_address

    @property
    def is_bootstrap_master(self):
        """Gets the is_bootstrap_master of this EdgeDeviceWithClusterInfo.  # noqa: E501


        :return: The is_bootstrap_master of this EdgeDeviceWithClusterInfo.  # noqa: E501
        :rtype: bool
        """
        return self._is_bootstrap_master

    @is_bootstrap_master.setter
    def is_bootstrap_master(self, is_bootstrap_master):
        """Sets the is_bootstrap_master of this EdgeDeviceWithClusterInfo.


        :param is_bootstrap_master: The is_bootstrap_master of this EdgeDeviceWithClusterInfo.  # noqa: E501
        :type: bool
        """
        if is_bootstrap_master is None:
            raise ValueError("Invalid value for `is_bootstrap_master`, must not be `None`")  # noqa: E501

        self._is_bootstrap_master = is_bootstrap_master

    @property
    def name(self):
        """Gets the name of this EdgeDeviceWithClusterInfo.  # noqa: E501

        Edge name. Maximum length edge name is determined by kubernetes. Name length limited to 60 as node name is the edge name plus a suffix. https://github.com/kubernetes/kubernetes/blob/master/staging/src/k8s.io/apimachinery/pkg/util/validation/validation.go  # noqa: E501

        :return: The name of this EdgeDeviceWithClusterInfo.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this EdgeDeviceWithClusterInfo.

        Edge name. Maximum length edge name is determined by kubernetes. Name length limited to 60 as node name is the edge name plus a suffix. https://github.com/kubernetes/kubernetes/blob/master/staging/src/k8s.io/apimachinery/pkg/util/validation/validation.go  # noqa: E501

        :param name: The name of this EdgeDeviceWithClusterInfo.  # noqa: E501
        :type: str
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def role(self):
        """Gets the role of this EdgeDeviceWithClusterInfo.  # noqa: E501


        :return: The role of this EdgeDeviceWithClusterInfo.  # noqa: E501
        :rtype: NodeRole
        """
        return self._role

    @role.setter
    def role(self, role):
        """Sets the role of this EdgeDeviceWithClusterInfo.


        :param role: The role of this EdgeDeviceWithClusterInfo.  # noqa: E501
        :type: NodeRole
        """

        self._role = role

    @property
    def serial_number(self):
        """Gets the serial_number of this EdgeDeviceWithClusterInfo.  # noqa: E501

        Edge device serial number  # noqa: E501

        :return: The serial_number of this EdgeDeviceWithClusterInfo.  # noqa: E501
        :rtype: str
        """
        return self._serial_number

    @serial_number.setter
    def serial_number(self, serial_number):
        """Sets the serial_number of this EdgeDeviceWithClusterInfo.

        Edge device serial number  # noqa: E501

        :param serial_number: The serial_number of this EdgeDeviceWithClusterInfo.  # noqa: E501
        :type: str
        """
        if serial_number is None:
            raise ValueError("Invalid value for `serial_number`, must not be `None`")  # noqa: E501

        self._serial_number = serial_number

    @property
    def subnet(self):
        """Gets the subnet of this EdgeDeviceWithClusterInfo.  # noqa: E501

        Edge subnet mask  # noqa: E501

        :return: The subnet of this EdgeDeviceWithClusterInfo.  # noqa: E501
        :rtype: str
        """
        return self._subnet

    @subnet.setter
    def subnet(self, subnet):
        """Sets the subnet of this EdgeDeviceWithClusterInfo.

        Edge subnet mask  # noqa: E501

        :param subnet: The subnet of this EdgeDeviceWithClusterInfo.  # noqa: E501
        :type: str
        """
        if subnet is None:
            raise ValueError("Invalid value for `subnet`, must not be `None`")  # noqa: E501

        self._subnet = subnet

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(EdgeDeviceWithClusterInfo, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, EdgeDeviceWithClusterInfo):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Karbon Platform Services API reference.

    OpenAPI documentation for public facing Karbon Platform Services API  This API documentation is generated from source code using go-swagger. Do not edit the generated kps_api.json directly!  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: karbon-platform-services-api@nutanix.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import kps_api
from api.node_api import NodeApi  # noqa: E501
from kps_api.rest import ApiException


class TestNodeApi(unittest.TestCase):
    """NodeApi unit test stubs"""

    def setUp(self):
        self.api = api.node_api.NodeApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_node_create(self):
        """Test case for node_create

        Create a node.  # noqa: E501
        """
        pass

    def test_node_delete(self):
        """Test case for node_delete

        Delete a node as specified by node ID.  # noqa: E501
        """
        pass

    def test_node_get(self):
        """Test case for node_get

        Get a node as specified by node ID.  # noqa: E501
        """
        pass

    def test_node_list(self):
        """Test case for node_list

        Get all service domain nodes.  # noqa: E501
        """
        pass

    def test_node_onboarded(self):
        """Test case for node_onboarded

        Update node post onboard info.  # noqa: E501
        """
        pass

    def test_node_update(self):
        """Test case for node_update

        Update a node as specified by node ID.  # noqa: E501
        """
        pass

    def test_project_get_nodes(self):
        """Test case for project_get_nodes

        Get all service domain nodes associated with a project by project ID.  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Karbon Platform Services API reference.

    OpenAPI documentation for public facing Karbon Platform Services API  This API documentation is generated from source code using go-swagger. Do not edit the generated kps_api.json directly!  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: karbon-platform-services-api@nutanix.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class Features(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'download_and_upgrade': 'bool',
        'high_mem_alert': 'bool',
        'multi_node_aware': 'bool',
        'project_user_kube_config': 'bool',
        'remote_ssh': 'bool',
        'url_upgrade': 'bool'
    }

    attribute_map = {
        'download_and_upgrade': 'downloadAndUpgrade',
        'high_mem_alert': 'highMemAlert',
        'multi_node_aware': 'multiNodeAware',
        'project_user_kube_config': 'projectUserKubeConfig',
        'remote_ssh': 'remoteSSH',
        'url_upgrade': 'urlUpgrade'
    }

    def __init__(self, download_and_upgrade=None, high_mem_alert=None, multi_node_aware=None, project_user_kube_config=None, remote_ssh=None, url_upgrade=None):  # noqa: E501
        """Features - a model defined in Swagger"""  # noqa: E501
        self._download_and_upgrade = None
        self._high_mem_alert = None
        self._multi_node_aware = None
        self._project_user_kube_config = None
        self._remote_ssh = None
        self._url_upgrade = None
        self.discriminator = None
        if download_and_upgrade is not None:
            self.download_and_upgrade = download_and_upgrade
        if high_mem_alert is not None:
            self.high_mem_alert = high_mem_alert
        if multi_node_aware is not None:
            self.multi_node_aware = multi_node_aware
        if project_user_kube_config is not None:
            self.project_user_kube_config = project_user_kube_config
        if remote_ssh is not None:
            self.remote_ssh = remote_ssh
        if url_upgrade is not None:
            self.url_upgrade = url_upgrade

    @property
    def download_and_upgrade(self):
        """Gets the download_and_upgrade of this Features.  # noqa: E501


        :return: The download_and_upgrade of this Features.  # noqa: E501
        :rtype: bool
        """
        return self._download_and_upgrade

    @download_and_upgrade.setter
    def download_and_upgrade(self, download_and_upgrade):
        """Sets the download_and_upgrade of this Features.


        :param download_and_upgrade: The download_and_upgrade of this Features.  # noqa: E501
        :type: bool
        """

        self._download_and_upgrade = download_and_upgrade

    @property
    def high_mem_alert(self):
        """Gets the high_mem_alert of this Features.  # noqa: E501


        :return: The high_mem_alert of this Features.  # noqa: E501
        :rtype: bool
        """
        return self._high_mem_alert

    @high_mem_alert.setter
    def high_mem_alert(self, high_mem_alert):
        """Sets the high_mem_alert of this Features.


        :param high_mem_alert: The high_mem_alert of this Features.  # noqa: E501
        :type: bool
        """

        self._high_mem_alert = high_mem_alert

    @property
    def multi_node_aware(self):
        """Gets the multi_node_aware of this Features.  # noqa: E501


        :return: The multi_node_aware of this Features.  # noqa: E501
        :rtype: bool
        """
        return self._multi_node_aware

    @multi_node_aware.setter
    def multi_node_aware(self, multi_node_aware):
        """Sets the multi_node_aware of this Features.


        :param multi_node_aware: The multi_node_aware of this Features.  # noqa: E501
        :type: bool
        """

        self._multi_node_aware = multi_node_aware

    @property
    def project_user_kube_config(self):
        """Gets the project_user_kube_config of this Features.  # noqa: E501


        :return: The project_user_kube_config of this Features.  # noqa: E501
        :rtype: bool
        """
        return self._project_user_kube_config

    @project_user_kube_config.setter
    def project_user_kube_config(self, project_user_kube_config):
        """Sets the project_user_kube_config of this Features.


        :param project_user_kube_config: The project_user_kube_config of this Features.  # noqa: E501
        :type: bool
        """

        self._project_user_kube_config = project_user_kube_config

    @property
    def remote_ssh(self):
        """Gets the remote_ssh of this Features.  # noqa: E501


        :return: The remote_ssh of this Features.  # noqa: E501
        :rtype: bool
        """
        return self._remote_ssh

    @remote_ssh.setter
    def remote_ssh(self, remote_ssh):
        """Sets the remote_ssh of this Features.


        :param remote_ssh: The remote_ssh of this Features.  # noqa: E501
        :type: bool
        """

        self._remote_ssh = remote_ssh

    @property
    def url_upgrade(self):
        """Gets the url_upgrade of this Features.  # noqa: E501


        :return: The url_upgrade of this Features.  # noqa: E501
        :rtype: bool
        """
        return self._url_upgrade

    @url_upgrade.setter
    def url_upgrade(self, url_upgrade):
        """Sets the url_upgrade of this Features.


        :param url_upgrade: The url_upgrade of this Features.  # noqa: E501
        :type: bool
        """

        self._url_upgrade = url_upgrade

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Features, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Features):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
